package index_data

import (
	"crypto/sha256"
	"encoding/hex"
	"encoding/json"
	"errors"
	"eta_gn/eta_bridge/global"
	"eta_gn/eta_bridge/services/alarm_msg"
	"eta_gn/eta_bridge/utils"
	"fmt"
	"hash"
	"io"
	"net/http"
	"strings"
	"time"
)

// GnBaseDataResp
// @Description: 基础返回
type GnBaseDataResp struct {
	Code string `json:"code"`
	Mesg string `json:"mesg"`
	Time string `json:"time"`
}

// GnBaseListResp
// @Description: 列表数据返回结构体
type GnBaseListResp struct {
	Result bool `json:"result"`
	Total  int  `json:"total"`
	Size   int  `json:"size"`
	PageNo int  `json:"pageNo"`
}

// GnEdbIndexListResp
// @Description: 指标列表请求返回结构体
type GnEdbIndexListResp struct {
	GnBaseDataResp
	Data GnEdbIndexListDataResp `json:"data"`
}

// GnEdbIndexListDataResp
// @Description: 指标列表返回结构体
type GnEdbIndexListDataResp struct {
	GnBaseListResp
	Records []GnEdbIndexResp `json:"records"`
}

// GnEdbIndexResp
// @Description: 单个指标响应结构体
type GnEdbIndexResp struct {
	//AREACODE          interface{} `json:"AREA_CODE"`
	//AOYDILATATIONHIGH interface{} `json:"AOY_DILATATION_HIGH"`
	//SULFURHIGH        interface{} `json:"SULFUR_HIGH"`
	INDEXID         int         `json:"INDEX_ID" description:"指标ID"`
	CREATETIME      string      `json:"CREATE_TIME" description:"创建时间"`
	ISVALIDDATA     int         `json:"IS_VALID_DATA" description:"数据是否生效"`
	INDEXLEVELONE   string      `json:"INDEX_LEVEL_ONE" description:"一级导航"`
	INDEXLEVELTWO   string      `json:"INDEX_LEVEL_TWO" description:"二级导航"`
	INDEXLEVELTHREE string      `json:"INDEX_LEVEL_THREE" description:"三级导航"`
	DATAFREQCODE    interface{} `json:"DATA_FREQ_CODE" description:"数据周期（频度）编码"`
	DATAFREQ        string      `json:"DATA_FREQ" description:"数据周期（频度）"`
	DATASOURCECODE  string      `json:"DATA_SOURCE_CODE" description:"数据来源编码"`
	DATASOURCE      string      `json:"DATA_SOURCE" description:"数据来源"`
	INDEXNAME       string      `json:"INDEX_NAME" description:"指标名称（系统内部使用）"`
	INDEXORIGINCODE string      `json:"INDEX_ORIGIN_CODE" description:"原始指标编码"`
	DATAUNIT        string      `json:"DATA_UNIT" description:"数据单位"`
	//INDEXDESC        interface{} `json:"INDEX_DESC" description:"指标简介"`
	CREATEORIGINTIME string `json:"CREATE_ORIGIN_TIME" description:"原始创建时间"`
	UPDATEORIGINTIME string `json:"UPDATE_ORIGIN_TIME" description:"原始修改时间"`
	UPDATETIME       string `json:"UPDATE_TIME" description:"修改时间"`
	INDEXORIGINNAME  string `json:"INDEX_ORIGIN_NAME" description:"原始指标名称"`
	//DES              interface{} `json:"DES" description:"备注"`
	UNIQUE_ID string `json:"UNIQUE_ID" description:"唯一id"`
}

type IndexInfoReq struct {
	//IndexId  string `json:"INDEX_ID"`
	UpdateTime string `json:"UPDATE_TIME"`
	Size       int    `json:"size"`
	PageNo     int    `json:"pageNo"`
	IndexId    string `json:"INDEX_ID"`
}

// GetIndexInfoList
// @Description: 获取指标列表
// @param param
// @param num
// @return resp
// @return err
func GetIndexInfoList(param IndexInfoReq) (resp GnEdbIndexListResp, err error) {
	defer func() {
		if err != nil {
			go alarm_msg.SendAlarmMsg("更新数据节点的token失败；ERR："+err.Error(), 3)
		}
	}()

	urlStr := global.CONFIG.Gn.DataEdbListUrl

	// 获取token
	token, err := GetGnAccessToken(false)
	if err != nil {
		return
	}

	// 请求
	result, err := HttpPostGn(urlStr, token, param, 0)
	if err != nil {
		return
	}

	//result := getJson2()

	//  解析响应结果
	err = json.Unmarshal(result, &resp)
	if err != nil {
		return
	}

	return
}

// GnEdbIndexValueListResp
// @Description: 指标明细数据列表返回结构体
type GnEdbIndexValueListResp struct {
	GnBaseDataResp
	Data GnEdbIndexValueListDataResp `json:"data"`
}

// GnEdbIndexValueListDataResp
// @Description: 指标明细数据列表返回结构体
type GnEdbIndexValueListDataResp struct {
	GnBaseListResp
	Records []GnEdbIndexValueResp `json:"records"`
}

// GnEdbIndexValueResp
// @Description: 单个指标明细数据返回结构体
type GnEdbIndexValueResp struct {
	//UPDATEORIGINTIME interface{} `json:"UPDATE_ORIGIN_TIME" description:"原始修改时间"`
	//VALUEDES         interface{} `json:"VALUE_DES" description:"指标值备注"`
	ISVALIDDATA int    `json:"IS_VALID_DATA" description:"数据是否生效"`
	DATADATE    string `json:"DATA_DATE" description:"数据日期"`
	UPDATETIME  string `json:"UPDATE_TIME" description:"修改时间"`
	VALUE       string `json:"VALUE" description:"指标值"`
	INDEXID     int    `json:"INDEX_ID" description:"指标ID"`
	//DES              interface{} `json:"DES" description:"备注"`
	//CREATEORIGINTIME interface{} `json:"CREATE_ORIGIN_TIME" description:"原始创建时间"`
	ID         int    `json:"ID" description:""`
	CREATETIME string `json:"CREATE_TIME" description:"创建时间"`
	UNIQUE_ID  string `json:"UNIQUE_ID" description:"唯一id"`
}

type IndexValueReq struct {
	UniqueId string `json:"UNIQUE_ID"`
	IndexId  string `json:"INDEX_ID"`
	DataDate string `json:"DATA_DATE"`
	Size     int    `json:"size"`
	PageNo   int    `json:"pageNo"`
}

// GetIndexValueList
// @Description: 获取指标明细列表
// @param param
// @param num
// @return resp
// @return err
func GetIndexValueList(param IndexValueReq) (resp GnEdbIndexValueListResp, err error) {
	defer func() {
		if err != nil {
			go alarm_msg.SendAlarmMsg("获取指标明细列表失败；ERR："+err.Error(), 3)
		}
	}()

	urlStr := global.CONFIG.Gn.DataEdbValueListUrl

	// 获取token
	token, err := GetGnAccessToken(false)
	if err != nil {
		return
	}

	// 请求
	result, err := HttpPostGn(urlStr, token, param, 0)
	if err != nil {
		return
	}

	//result := getJson3()

	//  解析响应结果
	err = json.Unmarshal(result, &resp)
	if err != nil {
		return
	}

	return
}

// GetGnAccessToken
// @Description: 获取AccessToken
// @param isRefresh
// @return token
// @return err
func GetGnAccessToken(isRefresh bool) (token string, err error) {
	defer func() {
		if err != nil {
			go alarm_msg.SendAlarmMsg("获取token失败，ERR："+err.Error(), 3)
		}
	}()
	redisKey := utils.CACHE_EDB_GN_DATA_SERVER_TOKEN
	token, redisErr := global.Rc.RedisString(redisKey)
	//如果从redis中accessToken 获取失败或者token为空了，再或者需要强制刷新了，那么重新获取accessToken
	if redisErr != nil || token == `` || isRefresh {
		token, err = refreshGnAccessToken()
		return
	}
	return
}

// refreshSmmAccessToken 强制刷新获取accessToken
func refreshGnAccessToken() (token string, err error) {
	defer func() {
		if err != nil {
			go alarm_msg.SendAlarmMsg("强制刷新获取accessToken失败；ERR："+err.Error(), 3)
		}
	}()
	tokenInfo, tmpErr := getGnAccessToken()
	if tmpErr != nil {
		err = tmpErr
		return
	}
	token = tokenInfo.Data
	//token存入redis
	redisKey := utils.CACHE_EDB_GN_DATA_SERVER_TOKEN
	err = global.Rc.Put(redisKey, token, time.Second*60*25)
	if err != nil {
		global.FILE_LOG.Errorf("获取数据节点的token成功；数据节点 token存入redis失败，ERR：%s", err.Error())
		return
	}
	return
}

// GnDataAccessResp
// @Description: 国能数据节点accessToken相应结构体
type GnDataAccessResp struct {
	Code string `json:"code"`
	Mesg string `json:"mesg"`
	Time string `json:"time"`
	Data string `json:"data"`
}

// getGnAccessToken token内部请求接口
func getGnAccessToken() (resp GnDataAccessResp, err error) {
	defer func() {
		if err != nil {
			go alarm_msg.SendAlarmMsg("更新的token失败；ERR："+err.Error(), 3)
		}
	}()

	timestamp, sign := GetSign()
	// 请求地址
	urlPath := fmt.Sprintf(`%s?accessKey=%s&timestamp=%d&sign=%s`, global.CONFIG.Gn.DataAccessTokenUrl, global.CONFIG.Gn.DataAccessKey, timestamp, sign)
	result, err := HttpGetGn(urlPath)
	if err != nil {
		return
	}

	//result := getJson()

	//  解析响应结果
	err = json.Unmarshal(result, &resp)
	if err != nil {
		return
	}

	if resp.Code != "000000" {
		err = errors.New(fmt.Sprintf("响应代码：%s，错误信息：%s", resp.Code, resp.Mesg))
		return
	}

	return
}

// HttpGetAuth
// @Description: get请求
// @author: Roc
// @datetime 2024-01-23 16:20:16
// @param urlPath string
// @return []byte
// @return error
func HttpGetGn(urlPath string) ([]byte, error) {
	if global.CONFIG.Gn.DataHost == `` {
		return nil, errors.New("数据节点同步接口地址为空")
	}
	// 请求地址
	getUrl := global.CONFIG.Gn.DataHost + urlPath
	client := &http.Client{}
	req, err := http.NewRequest("GET", getUrl, nil)
	if err != nil {
		return nil, err
	}
	resp, err := client.Do(req)
	if err != nil {
		return nil, err
	}
	defer resp.Body.Close()
	result, err := io.ReadAll(resp.Body)
	if err != nil {
		return nil, err
	}

	// 日志记录
	global.FILE_LOG.Debug("数据节点:地址：" + getUrl + ";\n返回参数:" + string(result))

	//  解析返回参数，判断是否是json
	if !json.Valid(result) {
		err = errors.New("返回参数不是json格式")
	}

	return result, err
}

// HttpPostGn
// @Description: post请求
// @param urlPath
// @param token
// @param postDataParams
// @param num
// @return []byte
// @return error
func HttpPostGn(urlPath, token string, postDataParams interface{}, num int) ([]byte, error) {
	if global.CONFIG.Gn.DataHost == `` {
		return nil, errors.New("国能数据平台地址为空")
	}
	// 请求地址
	postUrl := global.CONFIG.Gn.DataHost + urlPath

	var err error

	postDataByte, e := json.Marshal(postDataParams)
	if e != nil {
		err = fmt.Errorf("data json marshal err: %s", e.Error())
		return []byte{}, err
	}
	postData := string(postDataByte)

	body := io.NopCloser(strings.NewReader(postData))
	client := &http.Client{}
	req, err := http.NewRequest("POST", postUrl, body)
	if err != nil {
		return nil, err
	}
	req.Header.Set("content-Type", "application/json; charset=utf-8")
	req.Header.Set("Accept-Encoding", "application/json; charset=utf-8")
	req.Header.Set("Accept", "application/json; charset=utf-8")
	// 鉴权
	req.Header.Set("Authorization", token)

	resp, err := client.Do(req)
	if err != nil {
		return nil, err
	}
	defer resp.Body.Close()
	result, err := io.ReadAll(resp.Body)
	if err != nil {
		return nil, err
	}

	// 日志记录
	global.FILE_LOG.Debug("数据节点:地址：" + postUrl + ";\n Token：" + token + ";\n请求参数：" + postData + ";\n返回参数:" + string(result))

	//  解析返回参数，判断是否是json
	if !json.Valid(result) {
		err = errors.New("返回参数不是json格式")
		return []byte{}, err
	}

	var baseResp GnBaseDataResp
	//  解析响应结果
	err = json.Unmarshal(result, &baseResp)
	if err != nil {
		return []byte{}, err
	}

	//如果是token失效，同时只是第一次请求（没有尝试强制刷新token，那么重新请求）
	if (utils.InArrayByStr([]string{""}, baseResp.Code) || strings.Contains(baseResp.Mesg, `无效token`)) && num <= 0 {
		//token失效
		token, err = refreshGnAccessToken()
		if err != nil {
			return []byte{}, err
		}
		num++
		return HttpPostGn(urlPath, postData, token, num)
	} else if baseResp.Code != "000000" {
		err = errors.New(fmt.Sprintf("响应代码：%s，错误信息：%s", baseResp.Code, baseResp.Mesg))
		global.LOG.Info(fmt.Sprint("post data err:", baseResp.Mesg, ";url:", postUrl, ";response:", postData))

		return []byte{}, err
	}

	return result, err
}

// SHA256 计算给定字符串的SHA-256哈希值，并返回大写的十六进制表示形式。
func SHA256(strSrc string) string {
	return strings.ToUpper(hex.EncodeToString(encrypt([]byte(strSrc), sha256.New())))
}

// encrypt 使用指定的哈希算法计算输入字节的哈希值。
func encrypt(strSrc []byte, hasher hash.Hash) []byte {
	hasher.Write(strSrc)
	return hasher.Sum(nil)
}

func GetSign() (timestamp int64, sign string) {
	accessKey := global.CONFIG.Gn.DataAccessKey
	accessSecret := global.CONFIG.Gn.DataAccessSecret
	timestamp = time.Now().UnixNano() / int64(time.Millisecond)
	sign = SHA256(accessKey + fmt.Sprint(timestamp) + accessSecret)
	//fmt.Printf("timestamp : %d\n", timestamp)
	//fmt.Printf("sign: %s\n", sign)
	return
}

func getJson() []byte {
	str := `{"code":"-1","mesg":"签名错误","time":"2024-10-11T02:30:22.459Z","data":"签名错误"}`

	return []byte(str)
}

func getJson2() []byte {
	str := `{"code":"000000","mesg":"处理成功","time":"2024-10-11T05:51:13.361Z","data":{"result":true,"total":437,"size":20,"records":[{"AREA_CODE":null,"AOY_DILATATION_HIGH":null,"SULFUR_HIGH":null,"INDEX_ID":1,"DATA_SOURCE_CODE":"S03","COAL_USAGE":null,"M_HIGH":null,"CREATE_TIME":"2024-10-10 18:15:23","VDAF_HIGH":null,"DATA_TYPE":"综合指数","G_HIGH":null,"ENTITY_NAME":null,"GRIND_INDEX_HIGH":null,"INDEX_LEVEL_TWO":null,"AREA_NAME":null,"IS_VALID_DATA":1,"INDEX_LEVEL_THREE":null,"G_LOW":null,"Y_VALUE_LOW":null,"M_LOW":null,"PRODUCT_NAME":"","ASH_FUSION_HIGH":null,"COAL_CATEGORY":null,"CODETICLE_LOW":null,"INDEX_LEVEL_ONE":null,"ENTITY_CODE":null,"DATA_FREQ_CODE":null,"DATA_FREQ":"日度","Q_HIGH":null,"DATA_SOURCE":"mysteel","INDEX_NAME":"中国海运煤炭运价指数：综合指数（日度）","INDEX_ORIGIN_CODE":"ID00185072","DATA_UNIT":"点","INDEX_DESC":null,"CREATE_ORIGIN_TIME":"2019-11-14 20:00:54","PORT_NAME":"","ASH_FUSION_LOW":null,"ASH_HIGH":null,"UPDATE_ORIGIN_TIME":"2024-10-10 12:22:28","Y_VALUE_HIGH":null,"COAL_CLAS":null,"Q_LOW":null,"CODETICLE_HIGH":null,"UPDATE_TIME":"2024-10-10 18:15:23","INDEX_ORIGIN_NAME":"中国海运煤炭运价指数：综合指数（日度）","GRIND_INDEX_LOW":null,"ASH_LOW":null,"ENT_NAME":null,"AOY_DILATATION_LOW":null,"DES":null,"VDAF_LOW":null,"SULFUR_LOW":null},{"AREA_CODE":null,"AOY_DILATATION_HIGH":null,"SULFUR_HIGH":null,"INDEX_ID":2,"DATA_SOURCE_CODE":"S03","COAL_USAGE":null,"M_HIGH":null,"CREATE_TIME":"2024-10-10 18:15:23","VDAF_HIGH":null,"DATA_TYPE":"价格指数","G_HIGH":null,"ENTITY_NAME":null,"GRIND_INDEX_HIGH":null,"INDEX_LEVEL_TWO":null,"AREA_NAME":"中华人民共和国","IS_VALID_DATA":1,"INDEX_LEVEL_THREE":null,"G_LOW":null,"Y_VALUE_LOW":null,"M_LOW":null,"PRODUCT_NAME":"肥煤","ASH_FUSION_HIGH":null,"COAL_CATEGORY":null,"CODETICLE_LOW":null,"INDEX_LEVEL_ONE":null,"ENTITY_CODE":null,"DATA_FREQ_CODE":null,"DATA_FREQ":"日度","Q_HIGH":null,"DATA_SOURCE":"mysteel","INDEX_NAME":"肥煤：价格指数：中华人民共和国（日度）","INDEX_ORIGIN_CODE":"ID00278275","DATA_UNIT":"元/吨","INDEX_DESC":null,"CREATE_ORIGIN_TIME":"2020-03-27 18:49:44","PORT_NAME":"","ASH_FUSION_LOW":null,"ASH_HIGH":null,"UPDATE_ORIGIN_TIME":"2024-10-09 18:22:27","Y_VALUE_HIGH":null,"COAL_CLAS":null,"Q_LOW":null,"CODETICLE_HIGH":null,"UPDATE_TIME":"2024-10-10 18:15:23","INDEX_ORIGIN_NAME":"肥煤：价格指数：中华人民共和国（日度）","GRIND_INDEX_LOW":null,"ASH_LOW":null,"ENT_NAME":null,"AOY_DILATATION_LOW":null,"DES":null,"VDAF_LOW":null,"SULFUR_LOW":null},{"AREA_CODE":null,"AOY_DILATATION_HIGH":null,"SULFUR_HIGH":null,"INDEX_ID":3,"DATA_SOURCE_CODE":"S03","COAL_USAGE":null,"M_HIGH":null,"CREATE_TIME":"2024-10-10 18:15:23","VDAF_HIGH":null,"DATA_TYPE":"价格指数","G_HIGH":null,"ENTITY_NAME":null,"GRIND_INDEX_HIGH":null,"INDEX_LEVEL_TWO":null,"AREA_NAME":"中华人民共和国","IS_VALID_DATA":1,"INDEX_LEVEL_THREE":null,"G_LOW":null,"Y_VALUE_LOW":null,"M_LOW":null,"PRODUCT_NAME":"气煤","ASH_FUSION_HIGH":null,"COAL_CATEGORY":null,"CODETICLE_LOW":null,"INDEX_LEVEL_ONE":null,"ENTITY_CODE":null,"DATA_FREQ_CODE":null,"DATA_FREQ":"日度","Q_HIGH":null,"DATA_SOURCE":"mysteel","INDEX_NAME":"气煤：价格指数：中华人民共和国（日度）","INDEX_ORIGIN_CODE":"ID00279941","DATA_UNIT":"元/吨","INDEX_DESC":null,"CREATE_ORIGIN_TIME":"2020-03-27 19:22:33","PORT_NAME":"","ASH_FUSION_LOW":null,"ASH_HIGH":null,"UPDATE_ORIGIN_TIME":"2024-10-09 18:22:27","Y_VALUE_HIGH":null,"COAL_CLAS":null,"Q_LOW":null,"CODETICLE_HIGH":null,"UPDATE_TIME":"2024-10-10 18:15:23","INDEX_ORIGIN_NAME":"气煤：价格指数：中华人民共和国（日度）","GRIND_INDEX_LOW":null,"ASH_LOW":null,"ENT_NAME":null,"AOY_DILATATION_LOW":null,"DES":null,"VDAF_LOW":null,"SULFUR_LOW":null},{"AREA_CODE":null,"AOY_DILATATION_HIGH":null,"SULFUR_HIGH":null,"INDEX_ID":4,"DATA_SOURCE_CODE":"S03","COAL_USAGE":null,"M_HIGH":null,"CREATE_TIME":"2024-10-10 18:15:23","VDAF_HIGH":null,"DATA_TYPE":"价格指数","G_HIGH":null,"ENTITY_NAME":null,"GRIND_INDEX_HIGH":null,"INDEX_LEVEL_TWO":null,"AREA_NAME":"中华人民共和国","IS_VALID_DATA":1,"INDEX_LEVEL_THREE":null,"G_LOW":null,"Y_VALUE_LOW":null,"M_LOW":null,"PRODUCT_NAME":"瘦煤","ASH_FUSION_HIGH":null,"COAL_CATEGORY":null,"CODETICLE_LOW":null,"INDEX_LEVEL_ONE":null,"ENTITY_CODE":null,"DATA_FREQ_CODE":null,"DATA_FREQ":"日度","Q_HIGH":null,"DATA_SOURCE":"mysteel","INDEX_NAME":"瘦煤：价格指数：中华人民共和国（日度）","INDEX_ORIGIN_CODE":"ID00280036","DATA_UNIT":"元/吨","INDEX_DESC":null,"CREATE_ORIGIN_TIME":"2020-03-27 19:25:02","PORT_NAME":"","ASH_FUSION_LOW":null,"ASH_HIGH":null,"UPDATE_ORIGIN_TIME":"2024-10-09 18:22:27","Y_VALUE_HIGH":null,"COAL_CLAS":null,"Q_LOW":null,"CODETICLE_HIGH":null,"UPDATE_TIME":"2024-10-10 18:15:23","INDEX_ORIGIN_NAME":"瘦煤：价格指数：中华人民共和国（日度）","GRIND_INDEX_LOW":null,"ASH_LOW":null,"ENT_NAME":null,"AOY_DILATATION_LOW":null,"DES":null,"VDAF_LOW":null,"SULFUR_LOW":null},{"AREA_CODE":null,"AOY_DILATATION_HIGH":null,"SULFUR_HIGH":null,"INDEX_ID":5,"DATA_SOURCE_CODE":"S03","COAL_USAGE":null,"M_HIGH":null,"CREATE_TIME":"2024-10-10 18:15:23","VDAF_HIGH":null,"DATA_TYPE":"综合指数","G_HIGH":null,"ENTITY_NAME":null,"GRIND_INDEX_HIGH":null,"INDEX_LEVEL_TWO":null,"AREA_NAME":null,"IS_VALID_DATA":1,"INDEX_LEVEL_THREE":null,"G_LOW":null,"Y_VALUE_LOW":null,"M_LOW":null,"PRODUCT_NAME":"煤炭","ASH_FUSION_HIGH":null,"COAL_CATEGORY":null,"CODETICLE_LOW":null,"INDEX_LEVEL_ONE":null,"ENTITY_CODE":null,"DATA_FREQ_CODE":null,"DATA_FREQ":"月度","Q_HIGH":null,"DATA_SOURCE":"mysteel","INDEX_NAME":"煤炭：综合指数：长江干散货运价指数：长江航线（月度）","INDEX_ORIGIN_CODE":"ID00308789","DATA_UNIT":"2007年1月=1000","INDEX_DESC":null,"CREATE_ORIGIN_TIME":"2020-03-30 08:46:11","PORT_NAME":"","ASH_FUSION_LOW":null,"ASH_HIGH":null,"UPDATE_ORIGIN_TIME":"2024-09-05 12:22:16","Y_VALUE_HIGH":null,"COAL_CLAS":null,"Q_LOW":null,"CODETICLE_HIGH":null,"UPDATE_TIME":"2024-10-10 18:15:23","INDEX_ORIGIN_NAME":"煤炭：综合指数：长江干散货运价指数：长江航线（月度）","GRIND_INDEX_LOW":null,"ASH_LOW":null,"ENT_NAME":null,"AOY_DILATATION_LOW":null,"DES":null,"VDAF_LOW":null,"SULFUR_LOW":null},{"AREA_CODE":null,"AOY_DILATATION_HIGH":null,"SULFUR_HIGH":null,"INDEX_ID":6,"DATA_SOURCE_CODE":"S03","COAL_USAGE":null,"M_HIGH":null,"CREATE_TIME":"2024-10-10 18:15:23","VDAF_HIGH":null,"DATA_TYPE":"生产毛利","G_HIGH":null,"ENTITY_NAME":null,"GRIND_INDEX_HIGH":null,"INDEX_LEVEL_TWO":null,"AREA_NAME":"华东地区","IS_VALID_DATA":1,"INDEX_LEVEL_THREE":null,"G_LOW":null,"Y_VALUE_LOW":null,"M_LOW":null,"PRODUCT_NAME":"纯碱","ASH_FUSION_HIGH":null,"COAL_CATEGORY":null,"CODETICLE_LOW":null,"INDEX_LEVEL_ONE":null,"ENTITY_CODE":null,"DATA_FREQ_CODE":null,"DATA_FREQ":"周度","Q_HIGH":null,"DATA_SOURCE":"mysteel","INDEX_NAME":"纯碱：联碱法：生产毛利：华东地区（周度）","INDEX_ORIGIN_CODE":"ID00375049","DATA_UNIT":"元/吨","INDEX_DESC":null,"CREATE_ORIGIN_TIME":"2020-04-01 11:26:29","PORT_NAME":"","ASH_FUSION_LOW":null,"ASH_HIGH":null,"UPDATE_ORIGIN_TIME":"2024-10-08 15:22:46","Y_VALUE_HIGH":null,"COAL_CLAS":null,"Q_LOW":null,"CODETICLE_HIGH":null,"UPDATE_TIME":"2024-10-10 18:15:23","INDEX_ORIGIN_NAME":"纯碱：联碱法：生产毛利：华东地区（周度）","GRIND_INDEX_LOW":null,"ASH_LOW":null,"ENT_NAME":null,"AOY_DILATATION_LOW":null,"DES":null,"VDAF_LOW":null,"SULFUR_LOW":null},{"AREA_CODE":null,"AOY_DILATATION_HIGH":null,"SULFUR_HIGH":null,"INDEX_ID":7,"DATA_SOURCE_CODE":"S03","COAL_USAGE":null,"M_HIGH":null,"CREATE_TIME":"2024-10-10 18:15:23","VDAF_HIGH":null,"DATA_TYPE":"市场价格","G_HIGH":null,"ENTITY_NAME":null,"GRIND_INDEX_HIGH":null,"INDEX_LEVEL_TWO":null,"AREA_NAME":"东营市","IS_VALID_DATA":1,"INDEX_LEVEL_THREE":null,"G_LOW":null,"Y_VALUE_LOW":null,"M_LOW":null,"PRODUCT_NAME":"甲醇","ASH_FUSION_HIGH":null,"COAL_CATEGORY":null,"CODETICLE_LOW":null,"INDEX_LEVEL_ONE":null,"ENTITY_CODE":null,"DATA_FREQ_CODE":null,"DATA_FREQ":"日度","Q_HIGH":null,"DATA_SOURCE":"mysteel","INDEX_NAME":"甲醇：国标：市场价格：东营市（日度）","INDEX_ORIGIN_CODE":"ID00394098","DATA_UNIT":"元/吨","INDEX_DESC":null,"CREATE_ORIGIN_TIME":"2020-05-22 14:27:09","PORT_NAME":"","ASH_FUSION_LOW":null,"ASH_HIGH":null,"UPDATE_ORIGIN_TIME":"2024-10-10 12:22:28","Y_VALUE_HIGH":null,"COAL_CLAS":null,"Q_LOW":null,"CODETICLE_HIGH":null,"UPDATE_TIME":"2024-10-10 18:15:23","INDEX_ORIGIN_NAME":"甲醇：国标：市场价格：东营市（日度）","GRIND_INDEX_LOW":null,"ASH_LOW":null,"ENT_NAME":null,"AOY_DILATATION_LOW":null,"DES":null,"VDAF_LOW":null,"SULFUR_LOW":null},{"AREA_CODE":null,"AOY_DILATATION_HIGH":null,"SULFUR_HIGH":null,"INDEX_ID":8,"DATA_SOURCE_CODE":"S03","COAL_USAGE":null,"M_HIGH":null,"CREATE_TIME":"2024-10-10 18:15:23","VDAF_HIGH":null,"DATA_TYPE":"综合指数","G_HIGH":null,"ENTITY_NAME":null,"GRIND_INDEX_HIGH":null,"INDEX_LEVEL_TWO":null,"AREA_NAME":null,"IS_VALID_DATA":1,"INDEX_LEVEL_THREE":null,"G_LOW":null,"Y_VALUE_LOW":null,"M_LOW":null,"PRODUCT_NAME":"","ASH_FUSION_HIGH":null,"COAL_CATEGORY":null,"CODETICLE_LOW":null,"INDEX_LEVEL_ONE":null,"ENTITY_CODE":null,"DATA_FREQ_CODE":null,"DATA_FREQ":"日度","Q_HIGH":null,"DATA_SOURCE":"mysteel","INDEX_NAME":"中国沿海煤炭运价指数：综合指数（日度）","INDEX_ORIGIN_CODE":"ID00401371","DATA_UNIT":"2011年9月1日=1000","INDEX_DESC":null,"CREATE_ORIGIN_TIME":"2020-05-22 14:34:49","PORT_NAME":"","ASH_FUSION_LOW":null,"ASH_HIGH":null,"UPDATE_ORIGIN_TIME":"2024-10-09 18:22:27","Y_VALUE_HIGH":null,"COAL_CLAS":null,"Q_LOW":null,"CODETICLE_HIGH":null,"UPDATE_TIME":"2024-10-10 18:15:23","INDEX_ORIGIN_NAME":"中国沿海煤炭运价指数：综合指数（日度）","GRIND_INDEX_LOW":null,"ASH_LOW":null,"ENT_NAME":null,"AOY_DILATATION_LOW":null,"DES":null,"VDAF_LOW":null,"SULFUR_LOW":null},{"AREA_CODE":null,"AOY_DILATATION_HIGH":null,"SULFUR_HIGH":null,"INDEX_ID":9,"DATA_SOURCE_CODE":"S03","COAL_USAGE":null,"M_HIGH":null,"CREATE_TIME":"2024-10-10 18:15:23","VDAF_HIGH":null,"DATA_TYPE":"出厂价格","G_HIGH":null,"ENTITY_NAME":null,"GRIND_INDEX_HIGH":null,"INDEX_LEVEL_TWO":null,"AREA_NAME":"浙江省","IS_VALID_DATA":1,"INDEX_LEVEL_THREE":null,"G_LOW":null,"Y_VALUE_LOW":null,"M_LOW":null,"PRODUCT_NAME":"液化天然气","ASH_FUSION_HIGH":null,"COAL_CATEGORY":null,"CODETICLE_LOW":null,"INDEX_LEVEL_ONE":null,"ENTITY_CODE":null,"DATA_FREQ_CODE":null,"DATA_FREQ":"日度","Q_HIGH":null,"DATA_SOURCE":"mysteel","INDEX_NAME":"液化天然气：进口：出厂价格：浙江省：中海浙江宁波液化天然气有限公司（日度）","INDEX_ORIGIN_CODE":"ID00402102","DATA_UNIT":"元/吨","INDEX_DESC":null,"CREATE_ORIGIN_TIME":"2020-05-22 14:40:00","PORT_NAME":"","ASH_FUSION_LOW":null,"ASH_HIGH":null,"UPDATE_ORIGIN_TIME":"2024-10-10 09:22:18","Y_VALUE_HIGH":null,"COAL_CLAS":null,"Q_LOW":null,"CODETICLE_HIGH":null,"UPDATE_TIME":"2024-10-10 18:15:23","INDEX_ORIGIN_NAME":"液化天然气：进口：出厂价格：浙江省：中海浙江宁波液化天然气有限公司（日度）","GRIND_INDEX_LOW":null,"ASH_LOW":null,"ENT_NAME":"中海浙江宁波液化天然气有限公司","AOY_DILATATION_LOW":null,"DES":null,"VDAF_LOW":null,"SULFUR_LOW":null},{"AREA_CODE":null,"AOY_DILATATION_HIGH":null,"SULFUR_HIGH":null,"INDEX_ID":10,"DATA_SOURCE_CODE":"S03","COAL_USAGE":null,"M_HIGH":null,"CREATE_TIME":"2024-10-10 18:15:23","VDAF_HIGH":null,"DATA_TYPE":"市场主流价","G_HIGH":null,"ENTITY_NAME":null,"GRIND_INDEX_HIGH":null,"INDEX_LEVEL_TWO":null,"AREA_NAME":"江苏、浙江、上海","IS_VALID_DATA":1,"INDEX_LEVEL_THREE":null,"G_LOW":null,"Y_VALUE_LOW":null,"M_LOW":null,"PRODUCT_NAME":"针叶浆","ASH_FUSION_HIGH":null,"COAL_CATEGORY":null,"CODETICLE_LOW":null,"INDEX_LEVEL_ONE":null,"ENTITY_CODE":null,"DATA_FREQ_CODE":null,"DATA_FREQ":"日度","Q_HIGH":null,"DATA_SOURCE":"mysteel","INDEX_NAME":"针叶浆：市场主流价：江苏、浙江、上海：智利银星牌（日度）","INDEX_ORIGIN_CODE":"ID01026837","DATA_UNIT":"元/吨","INDEX_DESC":null,"CREATE_ORIGIN_TIME":"2020-08-21 06:08:38","PORT_NAME":"","ASH_FUSION_LOW":null,"ASH_HIGH":null,"UPDATE_ORIGIN_TIME":"2024-10-10 09:22:18","Y_VALUE_HIGH":null,"COAL_CLAS":null,"Q_LOW":null,"CODETICLE_HIGH":null,"UPDATE_TIME":"2024-10-10 18:15:23","INDEX_ORIGIN_NAME":"针叶浆：市场主流价：江苏、浙江、上海：智利银星牌（日度）","GRIND_INDEX_LOW":null,"ASH_LOW":null,"ENT_NAME":null,"AOY_DILATATION_LOW":null,"DES":null,"VDAF_LOW":null,"SULFUR_LOW":null},{"AREA_CODE":null,"AOY_DILATATION_HIGH":null,"SULFUR_HIGH":null,"INDEX_ID":11,"DATA_SOURCE_CODE":"S03","COAL_USAGE":null,"M_HIGH":null,"CREATE_TIME":"2024-10-10 18:15:23","VDAF_HIGH":null,"DATA_TYPE":"市场情绪指数","G_HIGH":null,"ENTITY_NAME":null,"GRIND_INDEX_HIGH":null,"INDEX_LEVEL_TWO":null,"AREA_NAME":null,"IS_VALID_DATA":1,"INDEX_LEVEL_THREE":null,"G_LOW":null,"Y_VALUE_LOW":null,"M_LOW":null,"PRODUCT_NAME":"焦煤","ASH_FUSION_HIGH":null,"COAL_CATEGORY":null,"CODETICLE_LOW":null,"INDEX_LEVEL_ONE":null,"ENTITY_CODE":null,"DATA_FREQ_CODE":null,"DATA_FREQ":"周度","Q_HIGH":null,"DATA_SOURCE":"mysteel","INDEX_NAME":"焦煤：11家期货公司：市场情绪指数（周度）","INDEX_ORIGIN_CODE":"ID00184495","DATA_UNIT":"点","INDEX_DESC":null,"CREATE_ORIGIN_TIME":"2019-11-14 19:59:22","PORT_NAME":"","ASH_FUSION_LOW":null,"ASH_HIGH":null,"UPDATE_ORIGIN_TIME":"2024-10-08 09:22:28","Y_VALUE_HIGH":null,"COAL_CLAS":null,"Q_LOW":null,"CODETICLE_HIGH":null,"UPDATE_TIME":"2024-10-10 18:15:23","INDEX_ORIGIN_NAME":"焦煤：11家期货公司：市场情绪指数（周度）","GRIND_INDEX_LOW":null,"ASH_LOW":null,"ENT_NAME":null,"AOY_DILATATION_LOW":null,"DES":null,"VDAF_LOW":null,"SULFUR_LOW":null},{"AREA_CODE":null,"AOY_DILATATION_HIGH":null,"SULFUR_HIGH":null,"INDEX_ID":12,"DATA_SOURCE_CODE":"S03","COAL_USAGE":null,"M_HIGH":null,"CREATE_TIME":"2024-10-10 18:15:23","VDAF_HIGH":null,"DATA_TYPE":"市场情绪指数","G_HIGH":null,"ENTITY_NAME":null,"GRIND_INDEX_HIGH":null,"INDEX_LEVEL_TWO":null,"AREA_NAME":null,"IS_VALID_DATA":1,"INDEX_LEVEL_THREE":null,"G_LOW":null,"Y_VALUE_LOW":null,"M_LOW":null,"PRODUCT_NAME":"焦煤","ASH_FUSION_HIGH":null,"COAL_CATEGORY":null,"CODETICLE_LOW":null,"INDEX_LEVEL_ONE":null,"ENTITY_CODE":null,"DATA_FREQ_CODE":null,"DATA_FREQ":"周度","Q_HIGH":null,"DATA_SOURCE":"mysteel","INDEX_NAME":"焦煤：150家独立焦化厂：市场情绪指数（周度）","INDEX_ORIGIN_CODE":"ID00184497","DATA_UNIT":"点","INDEX_DESC":null,"CREATE_ORIGIN_TIME":"2019-11-14 19:59:22","PORT_NAME":"","ASH_FUSION_LOW":null,"ASH_HIGH":null,"UPDATE_ORIGIN_TIME":"2024-10-08 09:22:28","Y_VALUE_HIGH":null,"COAL_CLAS":null,"Q_LOW":null,"CODETICLE_HIGH":null,"UPDATE_TIME":"2024-10-10 18:15:23","INDEX_ORIGIN_NAME":"焦煤：150家独立焦化厂：市场情绪指数（周度）","GRIND_INDEX_LOW":null,"ASH_LOW":null,"ENT_NAME":null,"AOY_DILATATION_LOW":null,"DES":null,"VDAF_LOW":null,"SULFUR_LOW":null},{"AREA_CODE":null,"AOY_DILATATION_HIGH":null,"SULFUR_HIGH":null,"INDEX_ID":13,"DATA_SOURCE_CODE":"S03","COAL_USAGE":null,"M_HIGH":null,"CREATE_TIME":"2024-10-10 18:15:23","VDAF_HIGH":null,"DATA_TYPE":"CIF价","G_HIGH":null,"ENTITY_NAME":null,"GRIND_INDEX_HIGH":null,"INDEX_LEVEL_TWO":null,"AREA_NAME":null,"IS_VALID_DATA":1,"INDEX_LEVEL_THREE":null,"G_LOW":null,"Y_VALUE_LOW":null,"M_LOW":null,"PRODUCT_NAME":"沫煤","ASH_FUSION_HIGH":null,"COAL_CATEGORY":null,"CODETICLE_LOW":null,"INDEX_LEVEL_ONE":null,"ENTITY_CODE":null,"DATA_FREQ_CODE":null,"DATA_FREQ":"日度","Q_HIGH":null,"DATA_SOURCE":"mysteel","INDEX_NAME":"沫煤：Q＜6000，A＜15，V＜30，S＜1，MT＜10：欧洲ARA港产区：CIF价：欧洲（日度）","INDEX_ORIGIN_CODE":"ID00188005","DATA_UNIT":"美元/吨","INDEX_DESC":null,"CREATE_ORIGIN_TIME":"2019-11-19 22:17:11","PORT_NAME":"","ASH_FUSION_LOW":null,"ASH_HIGH":null,"UPDATE_ORIGIN_TIME":"2024-10-10 12:22:28","Y_VALUE_HIGH":null,"COAL_CLAS":null,"Q_LOW":null,"CODETICLE_HIGH":null,"UPDATE_TIME":"2024-10-10 18:15:23","INDEX_ORIGIN_NAME":"沫煤：Q＜6000，A＜15，V＜30，S＜1，MT＜10：欧洲ARA港产区：CIF价：欧洲（日度）","GRIND_INDEX_LOW":null,"ASH_LOW":null,"ENT_NAME":null,"AOY_DILATATION_LOW":null,"DES":null,"VDAF_LOW":null,"SULFUR_LOW":null},{"AREA_CODE":null,"AOY_DILATATION_HIGH":null,"SULFUR_HIGH":null,"INDEX_ID":14,"DATA_SOURCE_CODE":"S03","COAL_USAGE":null,"M_HIGH":null,"CREATE_TIME":"2024-10-10 18:15:23","VDAF_HIGH":null,"DATA_TYPE":"价格指数","G_HIGH":null,"ENTITY_NAME":null,"GRIND_INDEX_HIGH":null,"INDEX_LEVEL_TWO":null,"AREA_NAME":null,"IS_VALID_DATA":1,"INDEX_LEVEL_THREE":null,"G_LOW":null,"Y_VALUE_LOW":null,"M_LOW":null,"PRODUCT_NAME":"水泥","ASH_FUSION_HIGH":null,"COAL_CATEGORY":null,"CODETICLE_LOW":null,"INDEX_LEVEL_ONE":null,"ENTITY_CODE":null,"DATA_FREQ_CODE":null,"DATA_FREQ":"日度","Q_HIGH":null,"DATA_SOURCE":"mysteel","INDEX_NAME":"水泥：价格指数（日度）","INDEX_ORIGIN_CODE":"ID00232483","DATA_UNIT":"元/吨","INDEX_DESC":null,"CREATE_ORIGIN_TIME":"2020-03-28 09:46:18","PORT_NAME":"","ASH_FUSION_LOW":null,"ASH_HIGH":null,"UPDATE_ORIGIN_TIME":"2024-10-09 18:22:27","Y_VALUE_HIGH":null,"COAL_CLAS":null,"Q_LOW":null,"CODETICLE_HIGH":null,"UPDATE_TIME":"2024-10-10 18:15:23","INDEX_ORIGIN_NAME":"水泥：价格指数（日度）","GRIND_INDEX_LOW":null,"ASH_LOW":null,"ENT_NAME":null,"AOY_DILATATION_LOW":null,"DES":null,"VDAF_LOW":null,"SULFUR_LOW":null},{"AREA_CODE":null,"AOY_DILATATION_HIGH":null,"SULFUR_HIGH":null,"INDEX_ID":15,"DATA_SOURCE_CODE":"S03","COAL_USAGE":null,"M_HIGH":null,"CREATE_TIME":"2024-10-10 18:15:23","VDAF_HIGH":null,"DATA_TYPE":"绝对价格","G_HIGH":null,"ENTITY_NAME":null,"GRIND_INDEX_HIGH":null,"INDEX_LEVEL_TWO":null,"AREA_NAME":"俄罗斯联邦","IS_VALID_DATA":1,"INDEX_LEVEL_THREE":null,"G_LOW":null,"Y_VALUE_LOW":null,"M_LOW":null,"PRODUCT_NAME":"瘦煤","ASH_FUSION_HIGH":null,"COAL_CATEGORY":null,"CODETICLE_LOW":null,"INDEX_LEVEL_ONE":null,"ENTITY_CODE":null,"DATA_FREQ_CODE":null,"DATA_FREQ":"日度","Q_HIGH":null,"DATA_SOURCE":"mysteel","INDEX_NAME":"瘦煤：进口：绝对价格：俄罗斯联邦（日度）","INDEX_ORIGIN_CODE":"ID00280023","DATA_UNIT":"元/吨","INDEX_DESC":null,"CREATE_ORIGIN_TIME":"2020-03-27 19:24:41","PORT_NAME":"","ASH_FUSION_LOW":null,"ASH_HIGH":null,"UPDATE_ORIGIN_TIME":"2024-10-10 12:22:28","Y_VALUE_HIGH":null,"COAL_CLAS":null,"Q_LOW":null,"CODETICLE_HIGH":null,"UPDATE_TIME":"2024-10-10 18:15:23","INDEX_ORIGIN_NAME":"瘦煤：进口：绝对价格：俄罗斯联邦（日度）","GRIND_INDEX_LOW":null,"ASH_LOW":null,"ENT_NAME":null,"AOY_DILATATION_LOW":null,"DES":null,"VDAF_LOW":null,"SULFUR_LOW":null},{"AREA_CODE":null,"AOY_DILATATION_HIGH":null,"SULFUR_HIGH":null,"INDEX_ID":16,"DATA_SOURCE_CODE":"S03","COAL_USAGE":null,"M_HIGH":null,"CREATE_TIME":"2024-10-10 18:15:23","VDAF_HIGH":null,"DATA_TYPE":"价格指数","G_HIGH":null,"ENTITY_NAME":null,"GRIND_INDEX_HIGH":null,"INDEX_LEVEL_TWO":null,"AREA_NAME":"中华人民共和国","IS_VALID_DATA":1,"INDEX_LEVEL_THREE":null,"G_LOW":null,"Y_VALUE_LOW":null,"M_LOW":null,"PRODUCT_NAME":"中硫主焦煤","ASH_FUSION_HIGH":null,"COAL_CATEGORY":null,"CODETICLE_LOW":null,"INDEX_LEVEL_ONE":null,"ENTITY_CODE":null,"DATA_FREQ_CODE":null,"DATA_FREQ":"日度","Q_HIGH":null,"DATA_SOURCE":"mysteel","INDEX_NAME":"中硫主焦煤：价格指数：中华人民共和国（日度）","INDEX_ORIGIN_CODE":"ID00280718","DATA_UNIT":"元/吨","INDEX_DESC":null,"CREATE_ORIGIN_TIME":"2020-03-27 19:39:32","PORT_NAME":"","ASH_FUSION_LOW":null,"ASH_HIGH":null,"UPDATE_ORIGIN_TIME":"2024-10-09 18:22:27","Y_VALUE_HIGH":null,"COAL_CLAS":null,"Q_LOW":null,"CODETICLE_HIGH":null,"UPDATE_TIME":"2024-10-10 18:15:23","INDEX_ORIGIN_NAME":"中硫主焦煤：价格指数：中华人民共和国（日度）","GRIND_INDEX_LOW":null,"ASH_LOW":null,"ENT_NAME":null,"AOY_DILATATION_LOW":null,"DES":null,"VDAF_LOW":null,"SULFUR_LOW":null},{"AREA_CODE":null,"AOY_DILATATION_HIGH":null,"SULFUR_HIGH":null,"INDEX_ID":17,"DATA_SOURCE_CODE":"S03","COAL_USAGE":null,"M_HIGH":null,"CREATE_TIME":"2024-10-10 18:15:23","VDAF_HIGH":null,"DATA_TYPE":"绝对参考价格","G_HIGH":null,"ENTITY_NAME":null,"GRIND_INDEX_HIGH":null,"INDEX_LEVEL_TWO":null,"AREA_NAME":"鄂尔多斯市","IS_VALID_DATA":1,"INDEX_LEVEL_THREE":null,"G_LOW":null,"Y_VALUE_LOW":null,"M_LOW":null,"PRODUCT_NAME":"动力煤","ASH_FUSION_HIGH":null,"COAL_CATEGORY":null,"CODETICLE_LOW":null,"INDEX_LEVEL_ONE":null,"ENTITY_CODE":null,"DATA_FREQ_CODE":null,"DATA_FREQ":"日度","Q_HIGH":null,"DATA_SOURCE":"mysteel","INDEX_NAME":"动力煤：Q＞5500：绝对参考价格：鄂尔多斯市（日度）","INDEX_ORIGIN_CODE":"RE00035841","DATA_UNIT":"元/吨","INDEX_DESC":null,"CREATE_ORIGIN_TIME":"2022-06-28 14:21:16","PORT_NAME":"","ASH_FUSION_LOW":null,"ASH_HIGH":null,"UPDATE_ORIGIN_TIME":"2024-09-23 18:22:10","Y_VALUE_HIGH":null,"COAL_CLAS":null,"Q_LOW":null,"CODETICLE_HIGH":null,"UPDATE_TIME":"2024-10-10 18:15:23","INDEX_ORIGIN_NAME":"动力煤：Q＞5500：绝对参考价格：鄂尔多斯市（日度）","GRIND_INDEX_LOW":null,"ASH_LOW":null,"ENT_NAME":null,"AOY_DILATATION_LOW":null,"DES":null,"VDAF_LOW":null,"SULFUR_LOW":null},{"AREA_CODE":null,"AOY_DILATATION_HIGH":null,"SULFUR_HIGH":null,"INDEX_ID":18,"DATA_SOURCE_CODE":"S03","COAL_USAGE":null,"M_HIGH":null,"CREATE_TIME":"2024-10-10 18:15:23","VDAF_HIGH":null,"DATA_TYPE":"绝对参考价格","G_HIGH":null,"ENTITY_NAME":null,"GRIND_INDEX_HIGH":null,"INDEX_LEVEL_TWO":null,"AREA_NAME":null,"IS_VALID_DATA":1,"INDEX_LEVEL_THREE":null,"G_LOW":null,"Y_VALUE_LOW":null,"M_LOW":null,"PRODUCT_NAME":"动力煤","ASH_FUSION_HIGH":null,"COAL_CATEGORY":null,"CODETICLE_LOW":null,"INDEX_LEVEL_ONE":null,"ENTITY_CODE":null,"DATA_FREQ_CODE":null,"DATA_FREQ":"日度","Q_HIGH":null,"DATA_SOURCE":"mysteel","INDEX_NAME":"动力煤：Q＞5500：绝对参考价格：秦皇岛港（日度）","INDEX_ORIGIN_CODE":"RE00035842","DATA_UNIT":"元/吨","INDEX_DESC":null,"CREATE_ORIGIN_TIME":"2022-06-28 14:21:16","PORT_NAME":"秦皇岛港","ASH_FUSION_LOW":null,"ASH_HIGH":null,"UPDATE_ORIGIN_TIME":"2024-10-10 09:22:18","Y_VALUE_HIGH":null,"COAL_CLAS":null,"Q_LOW":null,"CODETICLE_HIGH":null,"UPDATE_TIME":"2024-10-10 18:15:23","INDEX_ORIGIN_NAME":"动力煤：Q＞5500：绝对参考价格：秦皇岛港（日度）","GRIND_INDEX_LOW":null,"ASH_LOW":null,"ENT_NAME":null,"AOY_DILATATION_LOW":null,"DES":null,"VDAF_LOW":null,"SULFUR_LOW":null},{"AREA_CODE":null,"AOY_DILATATION_HIGH":null,"SULFUR_HIGH":null,"INDEX_ID":19,"DATA_SOURCE_CODE":"S03","COAL_USAGE":null,"M_HIGH":null,"CREATE_TIME":"2024-10-10 18:15:23","VDAF_HIGH":null,"DATA_TYPE":"绝对参考价格","G_HIGH":null,"ENTITY_NAME":null,"GRIND_INDEX_HIGH":null,"INDEX_LEVEL_TWO":null,"AREA_NAME":null,"IS_VALID_DATA":1,"INDEX_LEVEL_THREE":null,"G_LOW":null,"Y_VALUE_LOW":null,"M_LOW":null,"PRODUCT_NAME":"动力煤","ASH_FUSION_HIGH":null,"COAL_CATEGORY":null,"CODETICLE_LOW":null,"INDEX_LEVEL_ONE":null,"ENTITY_CODE":null,"DATA_FREQ_CODE":null,"DATA_FREQ":"日度","Q_HIGH":null,"DATA_SOURCE":"mysteel","INDEX_NAME":"动力煤：Q＞5500：绝对参考价格：广州港（日度）","INDEX_ORIGIN_CODE":"RE00035843","DATA_UNIT":"元/吨","INDEX_DESC":null,"CREATE_ORIGIN_TIME":"2022-06-28 14:21:16","PORT_NAME":"广州港","ASH_FUSION_LOW":null,"ASH_HIGH":null,"UPDATE_ORIGIN_TIME":"2024-10-10 09:22:18","Y_VALUE_HIGH":null,"COAL_CLAS":null,"Q_LOW":null,"CODETICLE_HIGH":null,"UPDATE_TIME":"2024-10-10 18:15:23","INDEX_ORIGIN_NAME":"动力煤：Q＞5500：绝对参考价格：广州港（日度）","GRIND_INDEX_LOW":null,"ASH_LOW":null,"ENT_NAME":null,"AOY_DILATATION_LOW":null,"DES":null,"VDAF_LOW":null,"SULFUR_LOW":null},{"AREA_CODE":null,"AOY_DILATATION_HIGH":null,"SULFUR_HIGH":null,"INDEX_ID":20,"DATA_SOURCE_CODE":"S03","COAL_USAGE":null,"M_HIGH":null,"CREATE_TIME":"2024-10-10 18:15:23","VDAF_HIGH":null,"DATA_TYPE":"绝对参考价格","G_HIGH":null,"ENTITY_NAME":null,"GRIND_INDEX_HIGH":null,"INDEX_LEVEL_TWO":null,"AREA_NAME":"大同市","IS_VALID_DATA":1,"INDEX_LEVEL_THREE":null,"G_LOW":null,"Y_VALUE_LOW":null,"M_LOW":null,"PRODUCT_NAME":"动力煤","ASH_FUSION_HIGH":null,"COAL_CATEGORY":null,"CODETICLE_LOW":null,"INDEX_LEVEL_ONE":null,"ENTITY_CODE":null,"DATA_FREQ_CODE":null,"DATA_FREQ":"日度","Q_HIGH":null,"DATA_SOURCE":"mysteel","INDEX_NAME":"动力煤：Q＞5500：绝对参考价格：大同市（日度）","INDEX_ORIGIN_CODE":"RE00035844","DATA_UNIT":"元/吨","INDEX_DESC":null,"CREATE_ORIGIN_TIME":"2022-06-28 14:21:16","PORT_NAME":"","ASH_FUSION_LOW":null,"ASH_HIGH":null,"UPDATE_ORIGIN_TIME":"2024-10-10 09:22:18","Y_VALUE_HIGH":null,"COAL_CLAS":null,"Q_LOW":null,"CODETICLE_HIGH":null,"UPDATE_TIME":"2024-10-10 18:15:23","INDEX_ORIGIN_NAME":"动力煤：Q＞5500：绝对参考价格：大同市（日度）","GRIND_INDEX_LOW":null,"ASH_LOW":null,"ENT_NAME":null,"AOY_DILATATION_LOW":null,"DES":null,"VDAF_LOW":null,"SULFUR_LOW":null}],"pageNo":1}}`
	str = `{"code":"000000","mesg":"处理成功","time":"2024-10-12T01:52:29.383Z","data":{"result":true,"total":2,"size":10,"records":[{"AREA_CODE":null,"AOY_DILATATION_HIGH":null,"SULFUR_HIGH":null,"INDEX_ID":882,"DATA_SOURCE_CODE":"S02","COAL_USAGE":null,"M_HIGH":null,"CREATE_TIME":"2024-10-11 20:51:35","VDAF_HIGH":null,"DATA_TYPE":null,"G_HIGH":null,"ENTITY_NAME":null,"GRIND_INDEX_HIGH":null,"INDEX_LEVEL_TWO":null,"AREA_NAME":null,"IS_VALID_DATA":1,"INDEX_LEVEL_THREE":null,"G_LOW":null,"Y_VALUE_LOW":null,"M_LOW":null,"PRODUCT_NAME":null,"ASH_FUSION_HIGH":null,"COAL_CATEGORY":null,"CODETICLE_LOW":null,"INDEX_LEVEL_ONE":null,"ENTITY_CODE":null,"DATA_FREQ_CODE":null,"DATA_FREQ":"周度","Q_HIGH":null,"DATA_SOURCE":"CCTD","INDEX_NAME":null,"INDEX_ORIGIN_CODE":"P00200030083","DATA_UNIT":"万吨","INDEX_DESC":null,"CREATE_ORIGIN_TIME":"2020-09-24 09:44:28","PORT_NAME":"曹妃甸港","ASH_FUSION_LOW":null,"ASH_HIGH":null,"UPDATE_ORIGIN_TIME":"2024-09-13 22:00:19","Y_VALUE_HIGH":null,"COAL_CLAS":null,"Q_LOW":null,"CODETICLE_HIGH":null,"UPDATE_TIME":"2024-10-11 20:51:35","INDEX_ORIGIN_NAME":"曹妃甸港煤炭库存(万吨)_鄂尔多斯市巴音孟克投资集团有限公司2","GRIND_INDEX_LOW":null,"ASH_LOW":null,"ENT_NAME":"鄂尔多斯市巴音孟克投资集团有限公司","AOY_DILATATION_LOW":null,"DES":null,"VDAF_LOW":null,"SULFUR_LOW":null},{"AREA_CODE":null,"AOY_DILATATION_HIGH":null,"SULFUR_HIGH":null,"INDEX_ID":883,"DATA_SOURCE_CODE":"S02","COAL_USAGE":null,"M_HIGH":null,"CREATE_TIME":"2024-10-11 20:51:35","VDAF_HIGH":null,"DATA_TYPE":null,"G_HIGH":null,"ENTITY_NAME":null,"GRIND_INDEX_HIGH":null,"INDEX_LEVEL_TWO":null,"AREA_NAME":null,"IS_VALID_DATA":1,"INDEX_LEVEL_THREE":null,"G_LOW":null,"Y_VALUE_LOW":null,"M_LOW":null,"PRODUCT_NAME":null,"ASH_FUSION_HIGH":null,"COAL_CATEGORY":null,"CODETICLE_LOW":null,"INDEX_LEVEL_ONE":null,"ENTITY_CODE":null,"DATA_FREQ_CODE":null,"DATA_FREQ":"周度","Q_HIGH":null,"DATA_SOURCE":"CCTD","INDEX_NAME":null,"INDEX_ORIGIN_CODE":"P00200030084","DATA_UNIT":"万吨","INDEX_DESC":null,"CREATE_ORIGIN_TIME":"2020-09-24 09:44:28","PORT_NAME":"曹妃甸港","ASH_FUSION_LOW":null,"ASH_HIGH":null,"UPDATE_ORIGIN_TIME":"2024-09-13 22:00:19","Y_VALUE_HIGH":null,"COAL_CLAS":null,"Q_LOW":null,"CODETICLE_HIGH":null,"UPDATE_TIME":"2024-10-11 20:51:35","INDEX_ORIGIN_NAME":"曹妃甸港煤炭库存(万吨)_山西安达源煤炭运销有限公司","GRIND_INDEX_LOW":null,"ASH_LOW":null,"ENT_NAME":"山西安达源煤炭运销有限公司","AOY_DILATATION_LOW":null,"DES":null,"VDAF_LOW":null,"SULFUR_LOW":null}],"pageNo":1}}`
	str = `{"code":"000000","mesg":"处理成功","time":"2024-10-11T05:51:13.361Z","data":{"result":true,"total":3,"size":20,"records":[{"AREA_CODE":null,"AOY_DILATATION_HIGH":null,"SULFUR_HIGH":null,"INDEX_ID":1,"DATA_SOURCE_CODE":"S03","COAL_USAGE":null,"M_HIGH":null,"CREATE_TIME":"2024-10-10 18:15:23","VDAF_HIGH":null,"DATA_TYPE":"综合指数","G_HIGH":null,"ENTITY_NAME":null,"GRIND_INDEX_HIGH":null,"INDEX_LEVEL_TWO":null,"AREA_NAME":null,"IS_VALID_DATA":1,"INDEX_LEVEL_THREE":null,"G_LOW":null,"Y_VALUE_LOW":null,"M_LOW":null,"PRODUCT_NAME":"","ASH_FUSION_HIGH":null,"COAL_CATEGORY":null,"CODETICLE_LOW":null,"INDEX_LEVEL_ONE":null,"ENTITY_CODE":null,"DATA_FREQ_CODE":null,"DATA_FREQ":"日度","Q_HIGH":null,"DATA_SOURCE":"mysteel","INDEX_NAME":"中国海运煤炭运价指数：综合指数（日度）","INDEX_ORIGIN_CODE":"ID00185072","DATA_UNIT":"点","INDEX_DESC":null,"CREATE_ORIGIN_TIME":"2019-11-14 20:00:54","PORT_NAME":"","ASH_FUSION_LOW":null,"ASH_HIGH":null,"UPDATE_ORIGIN_TIME":"2024-10-10 12:22:28","Y_VALUE_HIGH":null,"COAL_CLAS":null,"Q_LOW":null,"CODETICLE_HIGH":null,"UPDATE_TIME":"2024-10-10 18:15:23","INDEX_ORIGIN_NAME":"中国海运煤炭运价指数：综合指数（日度）","GRIND_INDEX_LOW":null,"ASH_LOW":null,"ENT_NAME":null,"AOY_DILATATION_LOW":null,"DES":null,"VDAF_LOW":null,"SULFUR_LOW":null},{"AREA_CODE":null,"AOY_DILATATION_HIGH":null,"SULFUR_HIGH":null,"INDEX_ID":2,"DATA_SOURCE_CODE":"S03","COAL_USAGE":null,"M_HIGH":null,"CREATE_TIME":"2024-10-10 18:15:23","VDAF_HIGH":null,"DATA_TYPE":"价格指数","G_HIGH":null,"ENTITY_NAME":null,"GRIND_INDEX_HIGH":null,"INDEX_LEVEL_TWO":null,"AREA_NAME":"中华人民共和国","IS_VALID_DATA":1,"INDEX_LEVEL_THREE":null,"G_LOW":null,"Y_VALUE_LOW":null,"M_LOW":null,"PRODUCT_NAME":"肥煤","ASH_FUSION_HIGH":null,"COAL_CATEGORY":null,"CODETICLE_LOW":null,"INDEX_LEVEL_ONE":null,"ENTITY_CODE":null,"DATA_FREQ_CODE":null,"DATA_FREQ":"日度","Q_HIGH":null,"DATA_SOURCE":"mysteel","INDEX_NAME":"肥煤：价格指数：中华人民共和国（日度）","INDEX_ORIGIN_CODE":"ID00278275","DATA_UNIT":"元/吨","INDEX_DESC":null,"CREATE_ORIGIN_TIME":"2020-03-27 18:49:44","PORT_NAME":"","ASH_FUSION_LOW":null,"ASH_HIGH":null,"UPDATE_ORIGIN_TIME":"2024-10-09 18:22:27","Y_VALUE_HIGH":null,"COAL_CLAS":null,"Q_LOW":null,"CODETICLE_HIGH":null,"UPDATE_TIME":"2024-10-10 18:15:23","INDEX_ORIGIN_NAME":"肥煤：价格指数：中华人民共和国（日度）","GRIND_INDEX_LOW":null,"ASH_LOW":null,"ENT_NAME":null,"AOY_DILATATION_LOW":null,"DES":null,"VDAF_LOW":null,"SULFUR_LOW":null},{"AREA_CODE":null,"AOY_DILATATION_HIGH":null,"SULFUR_HIGH":null,"INDEX_ID":3,"DATA_SOURCE_CODE":"S03","COAL_USAGE":null,"M_HIGH":null,"CREATE_TIME":"2024-10-10 18:15:23","VDAF_HIGH":null,"DATA_TYPE":"价格指数","G_HIGH":null,"ENTITY_NAME":null,"GRIND_INDEX_HIGH":null,"INDEX_LEVEL_TWO":null,"AREA_NAME":"中华人民共和国","IS_VALID_DATA":1,"INDEX_LEVEL_THREE":null,"G_LOW":null,"Y_VALUE_LOW":null,"M_LOW":null,"PRODUCT_NAME":"气煤","ASH_FUSION_HIGH":null,"COAL_CATEGORY":null,"CODETICLE_LOW":null,"INDEX_LEVEL_ONE":null,"ENTITY_CODE":null,"DATA_FREQ_CODE":null,"DATA_FREQ":"日度","Q_HIGH":null,"DATA_SOURCE":"mysteel","INDEX_NAME":"气煤：价格指数：中华人民共和国（日度）","INDEX_ORIGIN_CODE":"ID00279941","DATA_UNIT":"元/吨","INDEX_DESC":null,"CREATE_ORIGIN_TIME":"2020-03-27 19:22:33","PORT_NAME":"","ASH_FUSION_LOW":null,"ASH_HIGH":null,"UPDATE_ORIGIN_TIME":"2024-10-09 18:22:27","Y_VALUE_HIGH":null,"COAL_CLAS":null,"Q_LOW":null,"CODETICLE_HIGH":null,"UPDATE_TIME":"2024-10-10 18:15:23","INDEX_ORIGIN_NAME":"气煤：价格指数：中华人民共和国（日度）","GRIND_INDEX_LOW":null,"ASH_LOW":null,"ENT_NAME":null,"AOY_DILATATION_LOW":null,"DES":null,"VDAF_LOW":null,"SULFUR_LOW":null},{"AREA_CODE":null,"AOY_DILATATION_HIGH":null,"SULFUR_HIGH":null,"INDEX_ID":4,"DATA_SOURCE_CODE":"S03","COAL_USAGE":null,"M_HIGH":null,"CREATE_TIME":"2024-10-10 18:15:23","VDAF_HIGH":null,"DATA_TYPE":"价格指数","G_HIGH":null,"ENTITY_NAME":null,"GRIND_INDEX_HIGH":null,"INDEX_LEVEL_TWO":null,"AREA_NAME":"中华人民共和国","IS_VALID_DATA":1,"INDEX_LEVEL_THREE":null,"G_LOW":null,"Y_VALUE_LOW":null,"M_LOW":null,"PRODUCT_NAME":"瘦煤","ASH_FUSION_HIGH":null,"COAL_CATEGORY":null,"CODETICLE_LOW":null,"INDEX_LEVEL_ONE":null,"ENTITY_CODE":null,"DATA_FREQ_CODE":null,"DATA_FREQ":"日度","Q_HIGH":null,"DATA_SOURCE":"mysteel","INDEX_NAME":"瘦煤：价格指数：中华人民共和国（日度）","INDEX_ORIGIN_CODE":"ID00280036","DATA_UNIT":"元/吨","INDEX_DESC":null,"CREATE_ORIGIN_TIME":"2020-03-27 19:25:02","PORT_NAME":"","ASH_FUSION_LOW":null,"ASH_HIGH":null,"UPDATE_ORIGIN_TIME":"2024-10-09 18:22:27","Y_VALUE_HIGH":null,"COAL_CLAS":null,"Q_LOW":null,"CODETICLE_HIGH":null,"UPDATE_TIME":"2024-10-10 18:15:23","INDEX_ORIGIN_NAME":"瘦煤：价格指数：中华人民共和国（日度）","GRIND_INDEX_LOW":null,"ASH_LOW":null,"ENT_NAME":null,"AOY_DILATATION_LOW":null,"DES":null,"VDAF_LOW":null,"SULFUR_LOW":null},{"AREA_CODE":null,"AOY_DILATATION_HIGH":null,"SULFUR_HIGH":null,"INDEX_ID":5,"DATA_SOURCE_CODE":"S03","COAL_USAGE":null,"M_HIGH":null,"CREATE_TIME":"2024-10-10 18:15:23","VDAF_HIGH":null,"DATA_TYPE":"综合指数","G_HIGH":null,"ENTITY_NAME":null,"GRIND_INDEX_HIGH":null,"INDEX_LEVEL_TWO":null,"AREA_NAME":null,"IS_VALID_DATA":1,"INDEX_LEVEL_THREE":null,"G_LOW":null,"Y_VALUE_LOW":null,"M_LOW":null,"PRODUCT_NAME":"煤炭","ASH_FUSION_HIGH":null,"COAL_CATEGORY":null,"CODETICLE_LOW":null,"INDEX_LEVEL_ONE":null,"ENTITY_CODE":null,"DATA_FREQ_CODE":null,"DATA_FREQ":"月度","Q_HIGH":null,"DATA_SOURCE":"mysteel","INDEX_NAME":"煤炭：综合指数：长江干散货运价指数：长江航线（月度）","INDEX_ORIGIN_CODE":"ID00308789","DATA_UNIT":"2007年1月=1000","INDEX_DESC":null,"CREATE_ORIGIN_TIME":"2020-03-30 08:46:11","PORT_NAME":"","ASH_FUSION_LOW":null,"ASH_HIGH":null,"UPDATE_ORIGIN_TIME":"2024-09-05 12:22:16","Y_VALUE_HIGH":null,"COAL_CLAS":null,"Q_LOW":null,"CODETICLE_HIGH":null,"UPDATE_TIME":"2024-10-10 18:15:23","INDEX_ORIGIN_NAME":"煤炭：综合指数：长江干散货运价指数：长江航线（月度）","GRIND_INDEX_LOW":null,"ASH_LOW":null,"ENT_NAME":null,"AOY_DILATATION_LOW":null,"DES":null,"VDAF_LOW":null,"SULFUR_LOW":null},{"AREA_CODE":null,"AOY_DILATATION_HIGH":null,"SULFUR_HIGH":null,"INDEX_ID":6,"DATA_SOURCE_CODE":"S03","COAL_USAGE":null,"M_HIGH":null,"CREATE_TIME":"2024-10-10 18:15:23","VDAF_HIGH":null,"DATA_TYPE":"生产毛利","G_HIGH":null,"ENTITY_NAME":null,"GRIND_INDEX_HIGH":null,"INDEX_LEVEL_TWO":null,"AREA_NAME":"华东地区","IS_VALID_DATA":1,"INDEX_LEVEL_THREE":null,"G_LOW":null,"Y_VALUE_LOW":null,"M_LOW":null,"PRODUCT_NAME":"纯碱","ASH_FUSION_HIGH":null,"COAL_CATEGORY":null,"CODETICLE_LOW":null,"INDEX_LEVEL_ONE":null,"ENTITY_CODE":null,"DATA_FREQ_CODE":null,"DATA_FREQ":"周度","Q_HIGH":null,"DATA_SOURCE":"mysteel","INDEX_NAME":"纯碱：联碱法：生产毛利：华东地区（周度）","INDEX_ORIGIN_CODE":"ID00375049","DATA_UNIT":"元/吨","INDEX_DESC":null,"CREATE_ORIGIN_TIME":"2020-04-01 11:26:29","PORT_NAME":"","ASH_FUSION_LOW":null,"ASH_HIGH":null,"UPDATE_ORIGIN_TIME":"2024-10-08 15:22:46","Y_VALUE_HIGH":null,"COAL_CLAS":null,"Q_LOW":null,"CODETICLE_HIGH":null,"UPDATE_TIME":"2024-10-10 18:15:23","INDEX_ORIGIN_NAME":"纯碱：联碱法：生产毛利：华东地区（周度）","GRIND_INDEX_LOW":null,"ASH_LOW":null,"ENT_NAME":null,"AOY_DILATATION_LOW":null,"DES":null,"VDAF_LOW":null,"SULFUR_LOW":null},{"AREA_CODE":null,"AOY_DILATATION_HIGH":null,"SULFUR_HIGH":null,"INDEX_ID":7,"DATA_SOURCE_CODE":"S03","COAL_USAGE":null,"M_HIGH":null,"CREATE_TIME":"2024-10-10 18:15:23","VDAF_HIGH":null,"DATA_TYPE":"市场价格","G_HIGH":null,"ENTITY_NAME":null,"GRIND_INDEX_HIGH":null,"INDEX_LEVEL_TWO":null,"AREA_NAME":"东营市","IS_VALID_DATA":1,"INDEX_LEVEL_THREE":null,"G_LOW":null,"Y_VALUE_LOW":null,"M_LOW":null,"PRODUCT_NAME":"甲醇","ASH_FUSION_HIGH":null,"COAL_CATEGORY":null,"CODETICLE_LOW":null,"INDEX_LEVEL_ONE":null,"ENTITY_CODE":null,"DATA_FREQ_CODE":null,"DATA_FREQ":"日度","Q_HIGH":null,"DATA_SOURCE":"mysteel","INDEX_NAME":"甲醇：国标：市场价格：东营市（日度）","INDEX_ORIGIN_CODE":"ID00394098","DATA_UNIT":"元/吨","INDEX_DESC":null,"CREATE_ORIGIN_TIME":"2020-05-22 14:27:09","PORT_NAME":"","ASH_FUSION_LOW":null,"ASH_HIGH":null,"UPDATE_ORIGIN_TIME":"2024-10-10 12:22:28","Y_VALUE_HIGH":null,"COAL_CLAS":null,"Q_LOW":null,"CODETICLE_HIGH":null,"UPDATE_TIME":"2024-10-10 18:15:23","INDEX_ORIGIN_NAME":"甲醇：国标：市场价格：东营市（日度）","GRIND_INDEX_LOW":null,"ASH_LOW":null,"ENT_NAME":null,"AOY_DILATATION_LOW":null,"DES":null,"VDAF_LOW":null,"SULFUR_LOW":null},{"AREA_CODE":null,"AOY_DILATATION_HIGH":null,"SULFUR_HIGH":null,"INDEX_ID":8,"DATA_SOURCE_CODE":"S03","COAL_USAGE":null,"M_HIGH":null,"CREATE_TIME":"2024-10-10 18:15:23","VDAF_HIGH":null,"DATA_TYPE":"综合指数","G_HIGH":null,"ENTITY_NAME":null,"GRIND_INDEX_HIGH":null,"INDEX_LEVEL_TWO":null,"AREA_NAME":null,"IS_VALID_DATA":1,"INDEX_LEVEL_THREE":null,"G_LOW":null,"Y_VALUE_LOW":null,"M_LOW":null,"PRODUCT_NAME":"","ASH_FUSION_HIGH":null,"COAL_CATEGORY":null,"CODETICLE_LOW":null,"INDEX_LEVEL_ONE":null,"ENTITY_CODE":null,"DATA_FREQ_CODE":null,"DATA_FREQ":"日度","Q_HIGH":null,"DATA_SOURCE":"mysteel","INDEX_NAME":"中国沿海煤炭运价指数：综合指数（日度）","INDEX_ORIGIN_CODE":"ID00401371","DATA_UNIT":"2011年9月1日=1000","INDEX_DESC":null,"CREATE_ORIGIN_TIME":"2020-05-22 14:34:49","PORT_NAME":"","ASH_FUSION_LOW":null,"ASH_HIGH":null,"UPDATE_ORIGIN_TIME":"2024-10-09 18:22:27","Y_VALUE_HIGH":null,"COAL_CLAS":null,"Q_LOW":null,"CODETICLE_HIGH":null,"UPDATE_TIME":"2024-10-10 18:15:23","INDEX_ORIGIN_NAME":"中国沿海煤炭运价指数：综合指数（日度）","GRIND_INDEX_LOW":null,"ASH_LOW":null,"ENT_NAME":null,"AOY_DILATATION_LOW":null,"DES":null,"VDAF_LOW":null,"SULFUR_LOW":null},{"AREA_CODE":null,"AOY_DILATATION_HIGH":null,"SULFUR_HIGH":null,"INDEX_ID":9,"DATA_SOURCE_CODE":"S03","COAL_USAGE":null,"M_HIGH":null,"CREATE_TIME":"2024-10-10 18:15:23","VDAF_HIGH":null,"DATA_TYPE":"出厂价格","G_HIGH":null,"ENTITY_NAME":null,"GRIND_INDEX_HIGH":null,"INDEX_LEVEL_TWO":null,"AREA_NAME":"浙江省","IS_VALID_DATA":1,"INDEX_LEVEL_THREE":null,"G_LOW":null,"Y_VALUE_LOW":null,"M_LOW":null,"PRODUCT_NAME":"液化天然气","ASH_FUSION_HIGH":null,"COAL_CATEGORY":null,"CODETICLE_LOW":null,"INDEX_LEVEL_ONE":null,"ENTITY_CODE":null,"DATA_FREQ_CODE":null,"DATA_FREQ":"日度","Q_HIGH":null,"DATA_SOURCE":"mysteel","INDEX_NAME":"液化天然气：进口：出厂价格：浙江省：中海浙江宁波液化天然气有限公司（日度）","INDEX_ORIGIN_CODE":"ID00402102","DATA_UNIT":"元/吨","INDEX_DESC":null,"CREATE_ORIGIN_TIME":"2020-05-22 14:40:00","PORT_NAME":"","ASH_FUSION_LOW":null,"ASH_HIGH":null,"UPDATE_ORIGIN_TIME":"2024-10-10 09:22:18","Y_VALUE_HIGH":null,"COAL_CLAS":null,"Q_LOW":null,"CODETICLE_HIGH":null,"UPDATE_TIME":"2024-10-10 18:15:23","INDEX_ORIGIN_NAME":"液化天然气：进口：出厂价格：浙江省：中海浙江宁波液化天然气有限公司（日度）","GRIND_INDEX_LOW":null,"ASH_LOW":null,"ENT_NAME":"中海浙江宁波液化天然气有限公司","AOY_DILATATION_LOW":null,"DES":null,"VDAF_LOW":null,"SULFUR_LOW":null},{"AREA_CODE":null,"AOY_DILATATION_HIGH":null,"SULFUR_HIGH":null,"INDEX_ID":10,"DATA_SOURCE_CODE":"S03","COAL_USAGE":null,"M_HIGH":null,"CREATE_TIME":"2024-10-10 18:15:23","VDAF_HIGH":null,"DATA_TYPE":"市场主流价","G_HIGH":null,"ENTITY_NAME":null,"GRIND_INDEX_HIGH":null,"INDEX_LEVEL_TWO":null,"AREA_NAME":"江苏、浙江、上海","IS_VALID_DATA":1,"INDEX_LEVEL_THREE":null,"G_LOW":null,"Y_VALUE_LOW":null,"M_LOW":null,"PRODUCT_NAME":"针叶浆","ASH_FUSION_HIGH":null,"COAL_CATEGORY":null,"CODETICLE_LOW":null,"INDEX_LEVEL_ONE":null,"ENTITY_CODE":null,"DATA_FREQ_CODE":null,"DATA_FREQ":"日度","Q_HIGH":null,"DATA_SOURCE":"mysteel","INDEX_NAME":"针叶浆：市场主流价：江苏、浙江、上海：智利银星牌（日度）","INDEX_ORIGIN_CODE":"ID01026837","DATA_UNIT":"元/吨","INDEX_DESC":null,"CREATE_ORIGIN_TIME":"2020-08-21 06:08:38","PORT_NAME":"","ASH_FUSION_LOW":null,"ASH_HIGH":null,"UPDATE_ORIGIN_TIME":"2024-10-10 09:22:18","Y_VALUE_HIGH":null,"COAL_CLAS":null,"Q_LOW":null,"CODETICLE_HIGH":null,"UPDATE_TIME":"2024-10-10 18:15:23","INDEX_ORIGIN_NAME":"针叶浆：市场主流价：江苏、浙江、上海：智利银星牌（日度）","GRIND_INDEX_LOW":null,"ASH_LOW":null,"ENT_NAME":null,"AOY_DILATATION_LOW":null,"DES":null,"VDAF_LOW":null,"SULFUR_LOW":null},{"AREA_CODE":null,"AOY_DILATATION_HIGH":null,"SULFUR_HIGH":null,"INDEX_ID":11,"DATA_SOURCE_CODE":"S03","COAL_USAGE":null,"M_HIGH":null,"CREATE_TIME":"2024-10-10 18:15:23","VDAF_HIGH":null,"DATA_TYPE":"市场情绪指数","G_HIGH":null,"ENTITY_NAME":null,"GRIND_INDEX_HIGH":null,"INDEX_LEVEL_TWO":null,"AREA_NAME":null,"IS_VALID_DATA":1,"INDEX_LEVEL_THREE":null,"G_LOW":null,"Y_VALUE_LOW":null,"M_LOW":null,"PRODUCT_NAME":"焦煤","ASH_FUSION_HIGH":null,"COAL_CATEGORY":null,"CODETICLE_LOW":null,"INDEX_LEVEL_ONE":null,"ENTITY_CODE":null,"DATA_FREQ_CODE":null,"DATA_FREQ":"周度","Q_HIGH":null,"DATA_SOURCE":"mysteel","INDEX_NAME":"焦煤：11家期货公司：市场情绪指数（周度）","INDEX_ORIGIN_CODE":"ID00184495","DATA_UNIT":"点","INDEX_DESC":null,"CREATE_ORIGIN_TIME":"2019-11-14 19:59:22","PORT_NAME":"","ASH_FUSION_LOW":null,"ASH_HIGH":null,"UPDATE_ORIGIN_TIME":"2024-10-08 09:22:28","Y_VALUE_HIGH":null,"COAL_CLAS":null,"Q_LOW":null,"CODETICLE_HIGH":null,"UPDATE_TIME":"2024-10-10 18:15:23","INDEX_ORIGIN_NAME":"焦煤：11家期货公司：市场情绪指数（周度）","GRIND_INDEX_LOW":null,"ASH_LOW":null,"ENT_NAME":null,"AOY_DILATATION_LOW":null,"DES":null,"VDAF_LOW":null,"SULFUR_LOW":null},{"AREA_CODE":null,"AOY_DILATATION_HIGH":null,"SULFUR_HIGH":null,"INDEX_ID":12,"DATA_SOURCE_CODE":"S03","COAL_USAGE":null,"M_HIGH":null,"CREATE_TIME":"2024-10-10 18:15:23","VDAF_HIGH":null,"DATA_TYPE":"市场情绪指数","G_HIGH":null,"ENTITY_NAME":null,"GRIND_INDEX_HIGH":null,"INDEX_LEVEL_TWO":null,"AREA_NAME":null,"IS_VALID_DATA":1,"INDEX_LEVEL_THREE":null,"G_LOW":null,"Y_VALUE_LOW":null,"M_LOW":null,"PRODUCT_NAME":"焦煤","ASH_FUSION_HIGH":null,"COAL_CATEGORY":null,"CODETICLE_LOW":null,"INDEX_LEVEL_ONE":null,"ENTITY_CODE":null,"DATA_FREQ_CODE":null,"DATA_FREQ":"周度","Q_HIGH":null,"DATA_SOURCE":"mysteel","INDEX_NAME":"焦煤：150家独立焦化厂：市场情绪指数（周度）","INDEX_ORIGIN_CODE":"ID00184497","DATA_UNIT":"点","INDEX_DESC":null,"CREATE_ORIGIN_TIME":"2019-11-14 19:59:22","PORT_NAME":"","ASH_FUSION_LOW":null,"ASH_HIGH":null,"UPDATE_ORIGIN_TIME":"2024-10-08 09:22:28","Y_VALUE_HIGH":null,"COAL_CLAS":null,"Q_LOW":null,"CODETICLE_HIGH":null,"UPDATE_TIME":"2024-10-10 18:15:23","INDEX_ORIGIN_NAME":"焦煤：150家独立焦化厂：市场情绪指数（周度）","GRIND_INDEX_LOW":null,"ASH_LOW":null,"ENT_NAME":null,"AOY_DILATATION_LOW":null,"DES":null,"VDAF_LOW":null,"SULFUR_LOW":null},{"AREA_CODE":null,"AOY_DILATATION_HIGH":null,"SULFUR_HIGH":null,"INDEX_ID":13,"DATA_SOURCE_CODE":"S03","COAL_USAGE":null,"M_HIGH":null,"CREATE_TIME":"2024-10-10 18:15:23","VDAF_HIGH":null,"DATA_TYPE":"CIF价","G_HIGH":null,"ENTITY_NAME":null,"GRIND_INDEX_HIGH":null,"INDEX_LEVEL_TWO":null,"AREA_NAME":null,"IS_VALID_DATA":1,"INDEX_LEVEL_THREE":null,"G_LOW":null,"Y_VALUE_LOW":null,"M_LOW":null,"PRODUCT_NAME":"沫煤","ASH_FUSION_HIGH":null,"COAL_CATEGORY":null,"CODETICLE_LOW":null,"INDEX_LEVEL_ONE":null,"ENTITY_CODE":null,"DATA_FREQ_CODE":null,"DATA_FREQ":"日度","Q_HIGH":null,"DATA_SOURCE":"mysteel","INDEX_NAME":"沫煤：Q＜6000，A＜15，V＜30，S＜1，MT＜10：欧洲ARA港产区：CIF价：欧洲（日度）","INDEX_ORIGIN_CODE":"ID00188005","DATA_UNIT":"美元/吨","INDEX_DESC":null,"CREATE_ORIGIN_TIME":"2019-11-19 22:17:11","PORT_NAME":"","ASH_FUSION_LOW":null,"ASH_HIGH":null,"UPDATE_ORIGIN_TIME":"2024-10-10 12:22:28","Y_VALUE_HIGH":null,"COAL_CLAS":null,"Q_LOW":null,"CODETICLE_HIGH":null,"UPDATE_TIME":"2024-10-10 18:15:23","INDEX_ORIGIN_NAME":"沫煤：Q＜6000，A＜15，V＜30，S＜1，MT＜10：欧洲ARA港产区：CIF价：欧洲（日度）","GRIND_INDEX_LOW":null,"ASH_LOW":null,"ENT_NAME":null,"AOY_DILATATION_LOW":null,"DES":null,"VDAF_LOW":null,"SULFUR_LOW":null},{"AREA_CODE":null,"AOY_DILATATION_HIGH":null,"SULFUR_HIGH":null,"INDEX_ID":14,"DATA_SOURCE_CODE":"S03","COAL_USAGE":null,"M_HIGH":null,"CREATE_TIME":"2024-10-10 18:15:23","VDAF_HIGH":null,"DATA_TYPE":"价格指数","G_HIGH":null,"ENTITY_NAME":null,"GRIND_INDEX_HIGH":null,"INDEX_LEVEL_TWO":null,"AREA_NAME":null,"IS_VALID_DATA":1,"INDEX_LEVEL_THREE":null,"G_LOW":null,"Y_VALUE_LOW":null,"M_LOW":null,"PRODUCT_NAME":"水泥","ASH_FUSION_HIGH":null,"COAL_CATEGORY":null,"CODETICLE_LOW":null,"INDEX_LEVEL_ONE":null,"ENTITY_CODE":null,"DATA_FREQ_CODE":null,"DATA_FREQ":"日度","Q_HIGH":null,"DATA_SOURCE":"mysteel","INDEX_NAME":"水泥：价格指数（日度）","INDEX_ORIGIN_CODE":"ID00232483","DATA_UNIT":"元/吨","INDEX_DESC":null,"CREATE_ORIGIN_TIME":"2020-03-28 09:46:18","PORT_NAME":"","ASH_FUSION_LOW":null,"ASH_HIGH":null,"UPDATE_ORIGIN_TIME":"2024-10-09 18:22:27","Y_VALUE_HIGH":null,"COAL_CLAS":null,"Q_LOW":null,"CODETICLE_HIGH":null,"UPDATE_TIME":"2024-10-10 18:15:23","INDEX_ORIGIN_NAME":"水泥：价格指数（日度）","GRIND_INDEX_LOW":null,"ASH_LOW":null,"ENT_NAME":null,"AOY_DILATATION_LOW":null,"DES":null,"VDAF_LOW":null,"SULFUR_LOW":null},{"AREA_CODE":null,"AOY_DILATATION_HIGH":null,"SULFUR_HIGH":null,"INDEX_ID":15,"DATA_SOURCE_CODE":"S03","COAL_USAGE":null,"M_HIGH":null,"CREATE_TIME":"2024-10-10 18:15:23","VDAF_HIGH":null,"DATA_TYPE":"绝对价格","G_HIGH":null,"ENTITY_NAME":null,"GRIND_INDEX_HIGH":null,"INDEX_LEVEL_TWO":null,"AREA_NAME":"俄罗斯联邦","IS_VALID_DATA":1,"INDEX_LEVEL_THREE":null,"G_LOW":null,"Y_VALUE_LOW":null,"M_LOW":null,"PRODUCT_NAME":"瘦煤","ASH_FUSION_HIGH":null,"COAL_CATEGORY":null,"CODETICLE_LOW":null,"INDEX_LEVEL_ONE":null,"ENTITY_CODE":null,"DATA_FREQ_CODE":null,"DATA_FREQ":"日度","Q_HIGH":null,"DATA_SOURCE":"mysteel","INDEX_NAME":"瘦煤：进口：绝对价格：俄罗斯联邦（日度）","INDEX_ORIGIN_CODE":"ID00280023","DATA_UNIT":"元/吨","INDEX_DESC":null,"CREATE_ORIGIN_TIME":"2020-03-27 19:24:41","PORT_NAME":"","ASH_FUSION_LOW":null,"ASH_HIGH":null,"UPDATE_ORIGIN_TIME":"2024-10-10 12:22:28","Y_VALUE_HIGH":null,"COAL_CLAS":null,"Q_LOW":null,"CODETICLE_HIGH":null,"UPDATE_TIME":"2024-10-10 18:15:23","INDEX_ORIGIN_NAME":"瘦煤：进口：绝对价格：俄罗斯联邦（日度）","GRIND_INDEX_LOW":null,"ASH_LOW":null,"ENT_NAME":null,"AOY_DILATATION_LOW":null,"DES":null,"VDAF_LOW":null,"SULFUR_LOW":null},{"AREA_CODE":null,"AOY_DILATATION_HIGH":null,"SULFUR_HIGH":null,"INDEX_ID":16,"DATA_SOURCE_CODE":"S03","COAL_USAGE":null,"M_HIGH":null,"CREATE_TIME":"2024-10-10 18:15:23","VDAF_HIGH":null,"DATA_TYPE":"价格指数","G_HIGH":null,"ENTITY_NAME":null,"GRIND_INDEX_HIGH":null,"INDEX_LEVEL_TWO":null,"AREA_NAME":"中华人民共和国","IS_VALID_DATA":1,"INDEX_LEVEL_THREE":null,"G_LOW":null,"Y_VALUE_LOW":null,"M_LOW":null,"PRODUCT_NAME":"中硫主焦煤","ASH_FUSION_HIGH":null,"COAL_CATEGORY":null,"CODETICLE_LOW":null,"INDEX_LEVEL_ONE":null,"ENTITY_CODE":null,"DATA_FREQ_CODE":null,"DATA_FREQ":"日度","Q_HIGH":null,"DATA_SOURCE":"mysteel","INDEX_NAME":"中硫主焦煤：价格指数：中华人民共和国（日度）","INDEX_ORIGIN_CODE":"ID00280718","DATA_UNIT":"元/吨","INDEX_DESC":null,"CREATE_ORIGIN_TIME":"2020-03-27 19:39:32","PORT_NAME":"","ASH_FUSION_LOW":null,"ASH_HIGH":null,"UPDATE_ORIGIN_TIME":"2024-10-09 18:22:27","Y_VALUE_HIGH":null,"COAL_CLAS":null,"Q_LOW":null,"CODETICLE_HIGH":null,"UPDATE_TIME":"2024-10-10 18:15:23","INDEX_ORIGIN_NAME":"中硫主焦煤：价格指数：中华人民共和国（日度）","GRIND_INDEX_LOW":null,"ASH_LOW":null,"ENT_NAME":null,"AOY_DILATATION_LOW":null,"DES":null,"VDAF_LOW":null,"SULFUR_LOW":null},{"AREA_CODE":null,"AOY_DILATATION_HIGH":null,"SULFUR_HIGH":null,"INDEX_ID":17,"DATA_SOURCE_CODE":"S03","COAL_USAGE":null,"M_HIGH":null,"CREATE_TIME":"2024-10-10 18:15:23","VDAF_HIGH":null,"DATA_TYPE":"绝对参考价格","G_HIGH":null,"ENTITY_NAME":null,"GRIND_INDEX_HIGH":null,"INDEX_LEVEL_TWO":null,"AREA_NAME":"鄂尔多斯市","IS_VALID_DATA":1,"INDEX_LEVEL_THREE":null,"G_LOW":null,"Y_VALUE_LOW":null,"M_LOW":null,"PRODUCT_NAME":"动力煤","ASH_FUSION_HIGH":null,"COAL_CATEGORY":null,"CODETICLE_LOW":null,"INDEX_LEVEL_ONE":null,"ENTITY_CODE":null,"DATA_FREQ_CODE":null,"DATA_FREQ":"日度","Q_HIGH":null,"DATA_SOURCE":"mysteel","INDEX_NAME":"动力煤：Q＞5500：绝对参考价格：鄂尔多斯市（日度）","INDEX_ORIGIN_CODE":"RE00035841","DATA_UNIT":"元/吨","INDEX_DESC":null,"CREATE_ORIGIN_TIME":"2022-06-28 14:21:16","PORT_NAME":"","ASH_FUSION_LOW":null,"ASH_HIGH":null,"UPDATE_ORIGIN_TIME":"2024-09-23 18:22:10","Y_VALUE_HIGH":null,"COAL_CLAS":null,"Q_LOW":null,"CODETICLE_HIGH":null,"UPDATE_TIME":"2024-10-10 18:15:23","INDEX_ORIGIN_NAME":"动力煤：Q＞5500：绝对参考价格：鄂尔多斯市（日度）","GRIND_INDEX_LOW":null,"ASH_LOW":null,"ENT_NAME":null,"AOY_DILATATION_LOW":null,"DES":null,"VDAF_LOW":null,"SULFUR_LOW":null},{"AREA_CODE":null,"AOY_DILATATION_HIGH":null,"SULFUR_HIGH":null,"INDEX_ID":18,"DATA_SOURCE_CODE":"S03","COAL_USAGE":null,"M_HIGH":null,"CREATE_TIME":"2024-10-10 18:15:23","VDAF_HIGH":null,"DATA_TYPE":"绝对参考价格","G_HIGH":null,"ENTITY_NAME":null,"GRIND_INDEX_HIGH":null,"INDEX_LEVEL_TWO":null,"AREA_NAME":null,"IS_VALID_DATA":1,"INDEX_LEVEL_THREE":null,"G_LOW":null,"Y_VALUE_LOW":null,"M_LOW":null,"PRODUCT_NAME":"动力煤","ASH_FUSION_HIGH":null,"COAL_CATEGORY":null,"CODETICLE_LOW":null,"INDEX_LEVEL_ONE":null,"ENTITY_CODE":null,"DATA_FREQ_CODE":null,"DATA_FREQ":"日度","Q_HIGH":null,"DATA_SOURCE":"mysteel","INDEX_NAME":"动力煤：Q＞5500：绝对参考价格：秦皇岛港（日度）","INDEX_ORIGIN_CODE":"RE00035842","DATA_UNIT":"元/吨","INDEX_DESC":null,"CREATE_ORIGIN_TIME":"2022-06-28 14:21:16","PORT_NAME":"秦皇岛港","ASH_FUSION_LOW":null,"ASH_HIGH":null,"UPDATE_ORIGIN_TIME":"2024-10-10 09:22:18","Y_VALUE_HIGH":null,"COAL_CLAS":null,"Q_LOW":null,"CODETICLE_HIGH":null,"UPDATE_TIME":"2024-10-10 18:15:23","INDEX_ORIGIN_NAME":"动力煤：Q＞5500：绝对参考价格：秦皇岛港（日度）","GRIND_INDEX_LOW":null,"ASH_LOW":null,"ENT_NAME":null,"AOY_DILATATION_LOW":null,"DES":null,"VDAF_LOW":null,"SULFUR_LOW":null},{"AREA_CODE":null,"AOY_DILATATION_HIGH":null,"SULFUR_HIGH":null,"INDEX_ID":19,"DATA_SOURCE_CODE":"S03","COAL_USAGE":null,"M_HIGH":null,"CREATE_TIME":"2024-10-10 18:15:23","VDAF_HIGH":null,"DATA_TYPE":"绝对参考价格","G_HIGH":null,"ENTITY_NAME":null,"GRIND_INDEX_HIGH":null,"INDEX_LEVEL_TWO":null,"AREA_NAME":null,"IS_VALID_DATA":1,"INDEX_LEVEL_THREE":null,"G_LOW":null,"Y_VALUE_LOW":null,"M_LOW":null,"PRODUCT_NAME":"动力煤","ASH_FUSION_HIGH":null,"COAL_CATEGORY":null,"CODETICLE_LOW":null,"INDEX_LEVEL_ONE":null,"ENTITY_CODE":null,"DATA_FREQ_CODE":null,"DATA_FREQ":"日度","Q_HIGH":null,"DATA_SOURCE":"mysteel","INDEX_NAME":"动力煤：Q＞5500：绝对参考价格：广州港（日度）","INDEX_ORIGIN_CODE":"RE00035843","DATA_UNIT":"元/吨","INDEX_DESC":null,"CREATE_ORIGIN_TIME":"2022-06-28 14:21:16","PORT_NAME":"广州港","ASH_FUSION_LOW":null,"ASH_HIGH":null,"UPDATE_ORIGIN_TIME":"2024-10-10 09:22:18","Y_VALUE_HIGH":null,"COAL_CLAS":null,"Q_LOW":null,"CODETICLE_HIGH":null,"UPDATE_TIME":"2024-10-10 18:15:23","INDEX_ORIGIN_NAME":"动力煤：Q＞5500：绝对参考价格：广州港（日度）","GRIND_INDEX_LOW":null,"ASH_LOW":null,"ENT_NAME":null,"AOY_DILATATION_LOW":null,"DES":null,"VDAF_LOW":null,"SULFUR_LOW":null},{"AREA_CODE":null,"AOY_DILATATION_HIGH":null,"SULFUR_HIGH":null,"INDEX_ID":20,"DATA_SOURCE_CODE":"S03","COAL_USAGE":null,"M_HIGH":null,"CREATE_TIME":"2024-10-10 18:15:23","VDAF_HIGH":null,"DATA_TYPE":"绝对参考价格","G_HIGH":null,"ENTITY_NAME":null,"GRIND_INDEX_HIGH":null,"INDEX_LEVEL_TWO":null,"AREA_NAME":"大同市","IS_VALID_DATA":1,"INDEX_LEVEL_THREE":null,"G_LOW":null,"Y_VALUE_LOW":null,"M_LOW":null,"PRODUCT_NAME":"动力煤","ASH_FUSION_HIGH":null,"COAL_CATEGORY":null,"CODETICLE_LOW":null,"INDEX_LEVEL_ONE":null,"ENTITY_CODE":null,"DATA_FREQ_CODE":null,"DATA_FREQ":"日度","Q_HIGH":null,"DATA_SOURCE":"mysteel","INDEX_NAME":"动力煤：Q＞5500：绝对参考价格：大同市（日度）","INDEX_ORIGIN_CODE":"RE00035844","DATA_UNIT":"元/吨","INDEX_DESC":null,"CREATE_ORIGIN_TIME":"2022-06-28 14:21:16","PORT_NAME":"","ASH_FUSION_LOW":null,"ASH_HIGH":null,"UPDATE_ORIGIN_TIME":"2024-10-10 09:22:18","Y_VALUE_HIGH":null,"COAL_CLAS":null,"Q_LOW":null,"CODETICLE_HIGH":null,"UPDATE_TIME":"2024-10-10 18:15:23","INDEX_ORIGIN_NAME":"动力煤：Q＞5500：绝对参考价格：大同市（日度）","GRIND_INDEX_LOW":null,"ASH_LOW":null,"ENT_NAME":null,"AOY_DILATATION_LOW":null,"DES":null,"VDAF_LOW":null,"SULFUR_LOW":null},{"AREA_CODE":null,"AOY_DILATATION_HIGH":null,"SULFUR_HIGH":null,"INDEX_ID":884,"DATA_SOURCE_CODE":"S02","COAL_USAGE":null,"M_HIGH":null,"CREATE_TIME":"2024-10-11 20:51:35","VDAF_HIGH":null,"DATA_TYPE":null,"G_HIGH":null,"ENTITY_NAME":null,"GRIND_INDEX_HIGH":null,"INDEX_LEVEL_TWO":null,"AREA_NAME":null,"IS_VALID_DATA":1,"INDEX_LEVEL_THREE":null,"G_LOW":null,"Y_VALUE_LOW":null,"M_LOW":null,"PRODUCT_NAME":null,"ASH_FUSION_HIGH":null,"COAL_CATEGORY":null,"CODETICLE_LOW":null,"INDEX_LEVEL_ONE":null,"ENTITY_CODE":null,"DATA_FREQ_CODE":null,"DATA_FREQ":"周度","Q_HIGH":null,"DATA_SOURCE":"CCTD","INDEX_NAME":null,"INDEX_ORIGIN_CODE":"P00200030085","DATA_UNIT":"万吨","INDEX_DESC":null,"CREATE_ORIGIN_TIME":"2020-09-24 09:44:28","PORT_NAME":"曹妃甸港","ASH_FUSION_LOW":null,"ASH_HIGH":null,"UPDATE_ORIGIN_TIME":"2024-09-13 22:00:19","Y_VALUE_HIGH":null,"COAL_CLAS":null,"Q_LOW":null,"CODETICLE_HIGH":null,"UPDATE_TIME":"2024-10-11 20:51:35","INDEX_ORIGIN_NAME":"曹妃甸港煤炭库存(万吨)_鄂尔多斯市乌兰煤炭(集团)有限责任公司","GRIND_INDEX_LOW":null,"ASH_LOW":null,"ENT_NAME":"鄂尔多斯市乌兰煤炭(集团)有限责任公司","AOY_DILATATION_LOW":null,"DES":null,"VDAF_LOW":null,"SULFUR_LOW":null}],"pageNo":1}}`

	return []byte(str)
}

func getJson3() []byte {
	str := `{"code":"000000","mesg":"处理成功","time":"2024-10-11T06:12:32.195Z","data":{"result":true,"total":500344,"size":20,"records":[{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":"107.5","VALUE_DES":null,"LOW_VALUE":"107.5","IS_VALID_DATA":1,"DATA_DATE":"2024-06-30 00:00:00","UPDATE_TIME":"2024-10-10 18:15:38","VALUE":"107.5","INDEX_ID":0,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":1,"CREATE_TIME":"2024-10-10 18:15:38"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":"109.1","VALUE_DES":null,"LOW_VALUE":"109.1","IS_VALID_DATA":1,"DATA_DATE":"2024-03-31 00:00:00","UPDATE_TIME":"2024-10-10 18:15:38","VALUE":"109.1","INDEX_ID":0,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":2,"CREATE_TIME":"2024-10-10 18:15:38"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":"109","VALUE_DES":null,"LOW_VALUE":"109","IS_VALID_DATA":1,"DATA_DATE":"2023-12-31 00:00:00","UPDATE_TIME":"2024-10-10 18:15:38","VALUE":"109","INDEX_ID":0,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":3,"CREATE_TIME":"2024-10-10 18:15:38"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":"108.6","VALUE_DES":null,"LOW_VALUE":"108.6","IS_VALID_DATA":1,"DATA_DATE":"2023-09-30 00:00:00","UPDATE_TIME":"2024-10-10 18:15:38","VALUE":"108.6","INDEX_ID":0,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":4,"CREATE_TIME":"2024-10-10 18:15:38"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":"105.9","VALUE_DES":null,"LOW_VALUE":"105.9","IS_VALID_DATA":1,"DATA_DATE":"2023-06-30 00:00:00","UPDATE_TIME":"2024-10-10 18:15:38","VALUE":"105.9","INDEX_ID":0,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":5,"CREATE_TIME":"2024-10-10 18:15:38"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":"107.8","VALUE_DES":null,"LOW_VALUE":"107.8","IS_VALID_DATA":1,"DATA_DATE":"2023-03-31 00:00:00","UPDATE_TIME":"2024-10-10 18:15:38","VALUE":"107.8","INDEX_ID":0,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":6,"CREATE_TIME":"2024-10-10 18:15:38"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":"98.9","VALUE_DES":null,"LOW_VALUE":"98.9","IS_VALID_DATA":1,"DATA_DATE":"2022-12-31 00:00:00","UPDATE_TIME":"2024-10-10 18:15:38","VALUE":"98.9","INDEX_ID":0,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":7,"CREATE_TIME":"2024-10-10 18:15:38"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":"100.6","VALUE_DES":null,"LOW_VALUE":"100.6","IS_VALID_DATA":1,"DATA_DATE":"2022-09-30 00:00:00","UPDATE_TIME":"2024-10-10 18:15:38","VALUE":"100.6","INDEX_ID":0,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":8,"CREATE_TIME":"2024-10-10 18:15:38"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":"101.8","VALUE_DES":null,"LOW_VALUE":"101.8","IS_VALID_DATA":1,"DATA_DATE":"2022-06-30 00:00:00","UPDATE_TIME":"2024-10-10 18:15:38","VALUE":"101.8","INDEX_ID":0,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":9,"CREATE_TIME":"2024-10-10 18:15:38"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":"112.7","VALUE_DES":null,"LOW_VALUE":"112.7","IS_VALID_DATA":1,"DATA_DATE":"2022-03-31 00:00:00","UPDATE_TIME":"2024-10-10 18:15:38","VALUE":"112.7","INDEX_ID":0,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":10,"CREATE_TIME":"2024-10-10 18:15:38"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":"119.2","VALUE_DES":null,"LOW_VALUE":"119.2","IS_VALID_DATA":1,"DATA_DATE":"2021-12-31 00:00:00","UPDATE_TIME":"2024-10-10 18:15:38","VALUE":"119.2","INDEX_ID":0,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":11,"CREATE_TIME":"2024-10-10 18:15:38"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":"119.2","VALUE_DES":null,"LOW_VALUE":"119.2","IS_VALID_DATA":1,"DATA_DATE":"2021-09-30 00:00:00","UPDATE_TIME":"2024-10-10 18:15:38","VALUE":"119.2","INDEX_ID":0,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":12,"CREATE_TIME":"2024-10-10 18:15:38"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":"123.8","VALUE_DES":null,"LOW_VALUE":"123.8","IS_VALID_DATA":1,"DATA_DATE":"2021-06-30 00:00:00","UPDATE_TIME":"2024-10-10 18:15:38","VALUE":"123.8","INDEX_ID":0,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":13,"CREATE_TIME":"2024-10-10 18:15:38"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":"125.2","VALUE_DES":null,"LOW_VALUE":"125.2","IS_VALID_DATA":1,"DATA_DATE":"2021-03-31 00:00:00","UPDATE_TIME":"2024-10-10 18:15:38","VALUE":"125.2","INDEX_ID":0,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":14,"CREATE_TIME":"2024-10-10 18:15:38"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":"121.9146","VALUE_DES":null,"LOW_VALUE":"121.9146","IS_VALID_DATA":1,"DATA_DATE":"2020-12-31 00:00:00","UPDATE_TIME":"2024-10-10 18:15:38","VALUE":"121.9146","INDEX_ID":0,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":15,"CREATE_TIME":"2024-10-10 18:15:38"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":"121.1538","VALUE_DES":null,"LOW_VALUE":"121.1538","IS_VALID_DATA":1,"DATA_DATE":"2020-09-30 00:00:00","UPDATE_TIME":"2024-10-10 18:15:38","VALUE":"121.1538","INDEX_ID":0,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":16,"CREATE_TIME":"2024-10-10 18:15:38"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":"109.12","VALUE_DES":null,"LOW_VALUE":"109.12","IS_VALID_DATA":1,"DATA_DATE":"2020-06-30 00:00:00","UPDATE_TIME":"2024-10-10 18:15:38","VALUE":"109.12","INDEX_ID":0,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":17,"CREATE_TIME":"2024-10-10 18:15:38"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":"88.22","VALUE_DES":null,"LOW_VALUE":"88.22","IS_VALID_DATA":1,"DATA_DATE":"2020-03-31 00:00:00","UPDATE_TIME":"2024-10-10 18:15:38","VALUE":"88.22","INDEX_ID":0,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":18,"CREATE_TIME":"2024-10-10 18:15:38"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":"122.8","VALUE_DES":null,"LOW_VALUE":"122.8","IS_VALID_DATA":1,"DATA_DATE":"2019-12-31 00:00:00","UPDATE_TIME":"2024-10-10 18:15:38","VALUE":"122.8","INDEX_ID":0,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":19,"CREATE_TIME":"2024-10-10 18:15:38"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":"123.4","VALUE_DES":null,"LOW_VALUE":"123.4","IS_VALID_DATA":1,"DATA_DATE":"2019-09-30 00:00:00","UPDATE_TIME":"2024-10-10 18:15:38","VALUE":"123.4","INDEX_ID":0,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":20,"CREATE_TIME":"2024-10-10 18:15:38"}],"pageNo":1}}`
	str = `{"code":"000000","mesg":"处理成功","time":"2024-10-12T01:53:26.999Z","data":{"result":true,"total":20,"size":20,"records":[{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":"1.18","VALUE_DES":null,"LOW_VALUE":"1.18","IS_VALID_DATA":-1,"DATA_DATE":"2020-06-04 00:00:00","UPDATE_TIME":"2024-10-11 20:55:45","VALUE":"1.18","INDEX_ID":882,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":1,"CREATE_TIME":"2024-10-11 20:55:45"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":"1.68","VALUE_DES":null,"LOW_VALUE":"1.68","IS_VALID_DATA":-1,"DATA_DATE":"2020-06-27 00:00:00","UPDATE_TIME":"2024-10-11 20:55:45","VALUE":"1.68","INDEX_ID":882,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":2,"CREATE_TIME":"2024-10-11 20:55:45"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":null,"VALUE_DES":null,"LOW_VALUE":null,"IS_VALID_DATA":-1,"DATA_DATE":"2020-06-18 00:00:00","UPDATE_TIME":"2024-10-11 20:55:45","VALUE":null,"INDEX_ID":882,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":3,"CREATE_TIME":"2024-10-11 20:55:45"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":null,"VALUE_DES":null,"LOW_VALUE":null,"IS_VALID_DATA":-1,"DATA_DATE":"2020-05-21 00:00:00","UPDATE_TIME":"2024-10-11 20:55:45","VALUE":null,"INDEX_ID":882,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":4,"CREATE_TIME":"2024-10-11 20:55:45"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":"4.52","VALUE_DES":null,"LOW_VALUE":"4.52","IS_VALID_DATA":-1,"DATA_DATE":"2020-05-14 00:00:00","UPDATE_TIME":"2024-10-11 20:55:45","VALUE":"4.52","INDEX_ID":882,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":5,"CREATE_TIME":"2024-10-11 20:55:45"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":"1.16","VALUE_DES":null,"LOW_VALUE":"1.16","IS_VALID_DATA":-1,"DATA_DATE":"2020-05-10 00:00:00","UPDATE_TIME":"2024-10-11 20:55:45","VALUE":"1.16","INDEX_ID":882,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":6,"CREATE_TIME":"2024-10-11 20:55:45"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":"1.18","VALUE_DES":null,"LOW_VALUE":"1.18","IS_VALID_DATA":-1,"DATA_DATE":"2020-05-31 00:00:00","UPDATE_TIME":"2024-10-11 20:55:45","VALUE":"1.18","INDEX_ID":882,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":7,"CREATE_TIME":"2024-10-11 20:55:45"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":"5.82","VALUE_DES":null,"LOW_VALUE":"5.82","IS_VALID_DATA":-1,"DATA_DATE":"2020-04-20 00:00:00","UPDATE_TIME":"2024-10-11 20:55:45","VALUE":"5.82","INDEX_ID":882,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":8,"CREATE_TIME":"2024-10-11 20:55:45"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":"5.82","VALUE_DES":null,"LOW_VALUE":"5.82","IS_VALID_DATA":-1,"DATA_DATE":"2020-04-07 00:00:00","UPDATE_TIME":"2024-10-11 20:55:45","VALUE":"5.82","INDEX_ID":882,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":9,"CREATE_TIME":"2024-10-11 20:55:45"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":"1.29","VALUE_DES":null,"LOW_VALUE":"1.29","IS_VALID_DATA":-1,"DATA_DATE":"2020-05-05 00:00:00","UPDATE_TIME":"2024-10-11 20:55:45","VALUE":"1.29","INDEX_ID":882,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":10,"CREATE_TIME":"2024-10-11 20:55:45"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":"1.29","VALUE_DES":null,"LOW_VALUE":"1.29","IS_VALID_DATA":-1,"DATA_DATE":"2020-04-29 00:00:00","UPDATE_TIME":"2024-10-11 20:55:45","VALUE":"1.29","INDEX_ID":882,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":11,"CREATE_TIME":"2024-10-11 20:55:45"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":"7.42","VALUE_DES":null,"LOW_VALUE":"7.42","IS_VALID_DATA":-1,"DATA_DATE":"2020-03-12 00:00:00","UPDATE_TIME":"2024-10-11 20:55:45","VALUE":"7.42","INDEX_ID":882,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":12,"CREATE_TIME":"2024-10-11 20:55:45"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":"9.93","VALUE_DES":null,"LOW_VALUE":"9.93","IS_VALID_DATA":-1,"DATA_DATE":"2020-03-10 00:00:00","UPDATE_TIME":"2024-10-11 20:55:45","VALUE":"9.93","INDEX_ID":882,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":13,"CREATE_TIME":"2024-10-11 20:55:45"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":"7.42","VALUE_DES":null,"LOW_VALUE":"7.42","IS_VALID_DATA":-1,"DATA_DATE":"2020-03-29 00:00:00","UPDATE_TIME":"2024-10-11 20:55:45","VALUE":"7.42","INDEX_ID":882,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":14,"CREATE_TIME":"2024-10-11 20:55:45"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":"7.42","VALUE_DES":null,"LOW_VALUE":"7.42","IS_VALID_DATA":-1,"DATA_DATE":"2020-03-18 00:00:00","UPDATE_TIME":"2024-10-11 20:55:45","VALUE":"7.42","INDEX_ID":882,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":15,"CREATE_TIME":"2024-10-11 20:55:45"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":"9.93","VALUE_DES":null,"LOW_VALUE":"9.93","IS_VALID_DATA":-1,"DATA_DATE":"2020-02-14 00:00:00","UPDATE_TIME":"2024-10-11 20:55:45","VALUE":"9.93","INDEX_ID":882,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":16,"CREATE_TIME":"2024-10-11 20:55:45"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":"9.93","VALUE_DES":null,"LOW_VALUE":"9.93","IS_VALID_DATA":-1,"DATA_DATE":"2020-02-13 00:00:00","UPDATE_TIME":"2024-10-11 20:55:45","VALUE":"9.93","INDEX_ID":882,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":17,"CREATE_TIME":"2024-10-11 20:55:45"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":"9.93","VALUE_DES":null,"LOW_VALUE":"9.93","IS_VALID_DATA":-1,"DATA_DATE":"2020-03-02 00:00:00","UPDATE_TIME":"2024-10-11 20:55:45","VALUE":"9.93","INDEX_ID":882,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":18,"CREATE_TIME":"2024-10-11 20:55:45"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":"9.93","VALUE_DES":null,"LOW_VALUE":"9.93","IS_VALID_DATA":-1,"DATA_DATE":"2020-02-22 00:00:00","UPDATE_TIME":"2024-10-11 20:55:45","VALUE":"9.93","INDEX_ID":882,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":19,"CREATE_TIME":"2024-10-11 20:55:45"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":"4.06","VALUE_DES":null,"LOW_VALUE":"4.06","IS_VALID_DATA":-1,"DATA_DATE":"2020-01-05 00:00:00","UPDATE_TIME":"2024-10-11 20:55:45","VALUE":"4.06","INDEX_ID":882,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":20,"CREATE_TIME":"2024-10-11 20:55:45"}],"pageNo":1}}`
	str = `{"code":"000000","mesg":"处理成功","time":"2024-10-12T07:15:58.322Z","data":{"result":true,"total":20,"size":20,"records":[{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":null,"VALUE_DES":null,"LOW_VALUE":null,"IS_VALID_DATA":-1,"DATA_DATE":"2020-09-25 00:00:00","UPDATE_TIME":"2024-10-11 20:56:11","VALUE":null,"INDEX_ID":884,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":3241,"CREATE_TIME":"2024-10-11 20:56:11"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":"0.84","VALUE_DES":null,"LOW_VALUE":"0.84","IS_VALID_DATA":-1,"DATA_DATE":"2020-11-27 00:00:00","UPDATE_TIME":"2024-10-11 20:56:11","VALUE":"0.84","INDEX_ID":884,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":3242,"CREATE_TIME":"2024-10-11 20:56:11"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":null,"VALUE_DES":null,"LOW_VALUE":null,"IS_VALID_DATA":-1,"DATA_DATE":"2020-09-18 00:00:00","UPDATE_TIME":"2024-10-11 20:56:11","VALUE":null,"INDEX_ID":884,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":3243,"CREATE_TIME":"2024-10-11 20:56:11"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":null,"VALUE_DES":null,"LOW_VALUE":null,"IS_VALID_DATA":-1,"DATA_DATE":"2020-11-20 00:00:00","UPDATE_TIME":"2024-10-11 20:56:11","VALUE":null,"INDEX_ID":884,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":3244,"CREATE_TIME":"2024-10-11 20:56:11"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":null,"VALUE_DES":null,"LOW_VALUE":null,"IS_VALID_DATA":-1,"DATA_DATE":"2020-09-11 00:00:00","UPDATE_TIME":"2024-10-11 20:56:11","VALUE":null,"INDEX_ID":884,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":3245,"CREATE_TIME":"2024-10-11 20:56:11"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":null,"VALUE_DES":null,"LOW_VALUE":null,"IS_VALID_DATA":-1,"DATA_DATE":"2020-08-28 00:00:00","UPDATE_TIME":"2024-10-11 20:56:11","VALUE":null,"INDEX_ID":884,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":3246,"CREATE_TIME":"2024-10-11 20:56:11"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":null,"VALUE_DES":null,"LOW_VALUE":null,"IS_VALID_DATA":-1,"DATA_DATE":"2020-11-13 00:00:00","UPDATE_TIME":"2024-10-11 20:56:11","VALUE":null,"INDEX_ID":884,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":3247,"CREATE_TIME":"2024-10-11 20:56:11"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":null,"VALUE_DES":null,"LOW_VALUE":null,"IS_VALID_DATA":-1,"DATA_DATE":"2020-08-21 00:00:00","UPDATE_TIME":"2024-10-11 20:56:11","VALUE":null,"INDEX_ID":884,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":3248,"CREATE_TIME":"2024-10-11 20:56:11"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":null,"VALUE_DES":null,"LOW_VALUE":null,"IS_VALID_DATA":-1,"DATA_DATE":"2020-11-06 00:00:00","UPDATE_TIME":"2024-10-11 20:56:11","VALUE":null,"INDEX_ID":884,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":3249,"CREATE_TIME":"2024-10-11 20:56:11"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":null,"VALUE_DES":null,"LOW_VALUE":null,"IS_VALID_DATA":-1,"DATA_DATE":"2020-08-14 00:00:00","UPDATE_TIME":"2024-10-11 20:56:11","VALUE":null,"INDEX_ID":884,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":3250,"CREATE_TIME":"2024-10-11 20:56:11"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":null,"VALUE_DES":null,"LOW_VALUE":null,"IS_VALID_DATA":-1,"DATA_DATE":"2020-10-30 00:00:00","UPDATE_TIME":"2024-10-11 20:56:11","VALUE":null,"INDEX_ID":884,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":3251,"CREATE_TIME":"2024-10-11 20:56:11"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":null,"VALUE_DES":null,"LOW_VALUE":null,"IS_VALID_DATA":-1,"DATA_DATE":"2020-10-23 00:00:00","UPDATE_TIME":"2024-10-11 20:56:11","VALUE":null,"INDEX_ID":884,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":3252,"CREATE_TIME":"2024-10-11 20:56:11"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":null,"VALUE_DES":null,"LOW_VALUE":null,"IS_VALID_DATA":-1,"DATA_DATE":"2020-12-18 00:00:00","UPDATE_TIME":"2024-10-11 20:56:11","VALUE":null,"INDEX_ID":884,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":3253,"CREATE_TIME":"2024-10-11 20:56:11"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":null,"VALUE_DES":null,"LOW_VALUE":null,"IS_VALID_DATA":-1,"DATA_DATE":"2020-10-16 00:00:00","UPDATE_TIME":"2024-10-11 20:56:11","VALUE":null,"INDEX_ID":884,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":3254,"CREATE_TIME":"2024-10-11 20:56:11"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":null,"VALUE_DES":null,"LOW_VALUE":null,"IS_VALID_DATA":-1,"DATA_DATE":"2020-12-11 00:00:00","UPDATE_TIME":"2024-10-11 20:56:11","VALUE":null,"INDEX_ID":884,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":3255,"CREATE_TIME":"2024-10-11 20:56:11"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":null,"VALUE_DES":null,"LOW_VALUE":null,"IS_VALID_DATA":-1,"DATA_DATE":"2020-10-09 00:00:00","UPDATE_TIME":"2024-10-11 20:56:11","VALUE":null,"INDEX_ID":884,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":3256,"CREATE_TIME":"2024-10-11 20:56:11"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":null,"VALUE_DES":null,"LOW_VALUE":null,"IS_VALID_DATA":-1,"DATA_DATE":"2020-12-04 00:00:00","UPDATE_TIME":"2024-10-11 20:56:11","VALUE":null,"INDEX_ID":884,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":3257,"CREATE_TIME":"2024-10-11 20:56:11"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":"1.68","VALUE_DES":null,"LOW_VALUE":"1.68","IS_VALID_DATA":-1,"DATA_DATE":"2021-01-29 00:00:00","UPDATE_TIME":"2024-10-11 20:56:11","VALUE":"1.68","INDEX_ID":884,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":3258,"CREATE_TIME":"2024-10-11 20:56:11"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":null,"VALUE_DES":null,"LOW_VALUE":null,"IS_VALID_DATA":-1,"DATA_DATE":"2021-01-22 00:00:00","UPDATE_TIME":"2024-10-11 20:56:11","VALUE":null,"INDEX_ID":884,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":3259,"CREATE_TIME":"2024-10-11 20:56:11"},{"UPDATE_ORIGIN_TIME":null,"HIGH_VALUE":null,"VALUE_DES":null,"LOW_VALUE":null,"IS_VALID_DATA":-1,"DATA_DATE":"2021-01-15 00:00:00","UPDATE_TIME":"2024-10-11 20:56:11","VALUE":null,"INDEX_ID":884,"DES":null,"CREATE_ORIGIN_TIME":null,"ID":3260,"CREATE_TIME":"2024-10-11 20:56:11"}],"pageNo":1}}`

	return []byte(str)
}

// GetIndexInfoListV2
// @Description: 获取指标列表
// @param param
// @param num
// @return resp
// @return err
func GetIndexInfoListV2(param IndexInfoV2Req) (resp GnEdbIndexListResp, err error) {
	defer func() {
		if err != nil {
			go alarm_msg.SendAlarmMsg("获取指标列表失败2；ERR："+err.Error(), 3)
		}
	}()

	urlStr := global.CONFIG.Gn.DataEdbListUrl

	// 获取token
	token, err := GetGnAccessToken(false)
	if err != nil {
		return
	}

	// 请求
	result, err := HttpPostGn(urlStr, token, param, 0)
	if err != nil {
		return
	}

	//result := getJson2()

	//  解析响应结果
	err = json.Unmarshal(result, &resp)
	if err != nil {
		return
	}

	return
}

// type MarketOverviewResp struct {
// 	Code string             `json:"code"`
// 	Msg  string             `json:"msg"`
// 	Data MarketOverviewData `json:"data"`
// 	Time string             `json:"time"`
// }

type MarketOverviewData struct {
	Result  bool `json:"result"`
	Total   int  `json:"total"`
	Records []struct {
		Category         string `json:"CATEGORY"`
		Content          string `json:"CONTENT"`
		CreateOriginTime string `json:"CREATE_ORIGIN_TIME"`
		CreateTime       string `json:"CREATE_TIME"`
		DataDate         string `json:"DATA_DATE"`
		DataSource       string `json:"DATA_SOURCE"`
		DataSourceCode   string `json:"DATA_SOURCE_CODE"`
		Des              string `json:"DES"`
		Id               int    `json:"ID"`
		IsValidData      int    `json:"IS_VALID_DATA"`
		Person           string `json:"PERSON"`
		Titile           string `json:"TITILE"`
		UpdateOriginTime string `json:"UPDATE_ORIGIN_TIME"`
		UpdateTime       string `json:"UPDATE_TIME"`
	} `json:"records"`
}

func MockGnData() []byte {
	demoJson := `{
    "code": "000000",
    "msg": "处理成功",
    "time": "2024-09-24T07:12:40.020Z",
    "data": {
        "result": true,
        "total": 6,
        "records": [
            {
                "CATEGORY": "市场简况",
                "CONTENT": " 产地需求保持，煤价延续上涨。榆林区域销售良好，同时受保供加码影响，市场煤持续收缩，支撑煤价继续小涨。6100K价格1080元/吨,环比涨5元/吨；5800K价格1025元/吨，环比涨10元/吨。鄂尔多斯区域拉运积极性保持，市场情绪平稳。5500K价格890元/吨、5000K价格755元/吨、4500K价格645元/吨，均环比持平。晋北区域坑口采购需求持续向好，叠加港口价格上涨传导，报价普遍上调。大同5000K价格860元/吨，环比涨20元/吨；朔州5500KS1.5价格1010元/吨，环比涨20元/吨；朔州4500S1.6价格755元/吨，环比涨10元/吨；忻州5000S1.3价格815元/吨，环比涨15元/吨。\n 港口方面：近期产地市场煤持续收缩，发港调货难度增加，港口流通货源补充不足，支撑贸易商情绪保持乐观。而在高温、水电乏力和工业企业开工率上升影响下，电厂日耗保持高位，采购需求有所释放。5500K价格1160元/吨,环比涨5元/吨；5000K价格1030元/吨,环比涨5元/吨；4500K价格910元/吨，环比涨5元/吨。",
                "CREATE_ORIGIN_TIME": null,
                "CREATE_TIME": "2024-12-20 14:30:53",
                "DATA_DATE": "2022-08-17 00:00:00",
                "DATA_SOURCE": "CCTD",
                "DATA_SOURCE_CODE": "S02",
                "DES": null,
                "ID": 645,
                "IS_VALID_DATA": 1,
                "PERSON": null,
                "TITLE": "CCTD2022-08-17市场简况",
                "UPDATE_ORIGIN_TIME": null,
                "UPDATE_TIME": "2024-12-20 14:30:53"
            }
        ]
    }
}`

	return []byte(demoJson)
}

type MarketOverviewResp struct {
	Code string `json:"code"`
	Msg  string `json:"msg"`
	Time string `json:"time"`
	Data struct {
		Result  bool `json:"result"`
		Total   int  `json:"total"`
		Records []struct {
			Category         string `json:"CATEGORY"`
			Content          string `json:"CONTENT"`
			CreateOriginTime string `json:"CREATE_ORIGIN_TIME"`
			CreateTime       string `json:"CREATE_TIME"`
			DataDate         string `json:"DATA_DATE"`
			DataSource       string `json:"DATA_SOURCE"`
			DataSourceCode   string `json:"DATA_SOURCE_CODE"`
			Des              string `json:"DES"`
			ID               int    `json:"ID"`
			IsValidData      int    `json:"IS_VALID_DATA"`
			Person           string `json:"PERSON"`
			Title            string `json:"TITLE"`
			UpdateOriginTime string `json:"UPDATE_ORIGIN_TIME"`
			UpdateTime       string `json:"UPDATE_TIME"`
		} `json:"records"`
	} `json:"data"`
}

func GetMarketOverview(param interface{}) (resp *MarketOverviewResp, err error) {
	defer func() {
		if err != nil {
			go alarm_msg.SendAlarmMsg("获取市场简况失败；ERR："+err.Error(), 3)
		}
	}()

	// urlStr := global.CONFIG.Gn.DataAccessMarketUrl

	result := MockGnData()
	// // 获取token
	// token, err := GetGnAccessToken(false)
	// if err != nil {
	// 	return
	// }

	// // 请求
	// result, err := HttpPostGn(urlStr, token, param, 0)
	// if err != nil {
	// 	return
	// }

	//  解析响应结果
	err = json.Unmarshal(result, &resp)
	if err != nil {
		return
	}
	return
}
